namespace InstrumentDrivers
{
    using System;
    using System.Runtime.InteropServices;


    public class rssgs : object, System.IDisposable
    {

        private System.Runtime.InteropServices.HandleRef _handle;

        private bool _disposed = true;

        ~rssgs() { Dispose(false); }


        /// <summary>
        /// This function creates an IVI instrument driver session, typically using the C session instrument handle.
        /// </summary>
        /// <param name="Instrument_Handle">
        /// The instrument handle that is used to create an IVI instrument driver session.
        /// </param>
        public rssgs(System.IntPtr Instrument_Handle)
        {
            this._handle = new System.Runtime.InteropServices.HandleRef(this, Instrument_Handle);
            this._disposed = false;
        }

        /// <summary>
        /// This function performs the following initialization actions:
        /// 
        /// - Opens a session to the Default Resource Manager resource and a session to the specified device using the interface and address specified in the Resource_Name control.
        /// 
        /// - Performs an identification query on the Instrument.
        /// 
        /// - Resets the instrument to a known state.
        /// 
        /// - Sends initialization commands to the instrument that set any necessary programmatic variables such as Headers Off, Short Command form, and Data Transfer Binary to the state necessary for the operation of the instrument driver.
        /// 
        /// - Returns an Instrument Handle which is used to differentiate between different sessions of this instrument driver.
        /// 
        /// - Each time this function is invoked a Unique Session is opened.  It is possible to have more than one session open for the same resource.
        /// 
        /// </summary>
        /// <param name="Resource_Name">
        /// This control specifies the interface and address of the device that is to be initialized (Instrument Descriptor). The exact grammar to be used in this control is shown in the note below. 
        /// 
        /// Default Value:  "GPIB::28"
        /// 
        /// Notes:
        /// 
        /// (1) Based on the Instrument Descriptor, this operation establishes a communication session with a device.  The grammar for the Instrument Descriptor is shown below.  Optional parameters are shown in square brackets ([]).
        /// 
        /// Interface   Grammar
        /// ------------------------------------------------------
        /// GPIB        GPIB[board]::primary address[::secondary address]
        ///             [::INSTR]
        /// VXI-11      TCPIP::remote_host::INSTR 
        /// USB         USB::&lt;vendor Id&gt;::&lt;product Id&gt;::&lt;serial number&gt;
        ///             
        /// The GPIB keyword is used for GPIB interface.
        /// The TCPIP keyword is used for VXI-11 interface.
        /// The USB keyword is used for USB interface, where                           
        ///  &lt;vendor Id&gt; is 0x0AAD for Rohde&amp;Schwarz                                    
        ///  &lt;product Id&gt; is 0x0054 for SMB100A                                         
        ///  &lt;serial number&gt; is Serial number (on the rear panel of                     
        ///  the instrument). For example 100001.
        /// 
        /// Examples:
        /// (1) GPIB   - "GPIB::28::INSTR"
        /// (2) VXI-11 - "TCPIP::192.168.1.33::INSTR"
        /// (3) USB    - "USB::0xAAD::0x0054::100001::INSTR"
        /// 
        /// The default value for optional parameters are shown below.
        /// 
        /// Optional Parameter          Default Value
        /// -----------------------------------------
        /// board                       0
        /// secondary address           none - 31
        /// 
        /// </param>
        /// <param name="ID_Query">
        /// This control specifies if an ID Query is sent to the instrument during the initialization procedure.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Skip Query
        /// VI_TRUE  (1) - Do Query (Default Value)
        /// 
        /// Notes:
        ///    
        /// (1) Under normal circumstances the ID Query ensures that the instrument initialized is the type supported by this driver. However circumstances may arise where it is undesirable to send an ID Query to the instrument.  In those cases; set this control to "Skip Query" and this function will initialize the selected interface, without doing an ID Query.
        /// 
        /// </param>
        /// <param name="Reset_Device">
        /// This control specifies if the instrument is to be reset to its power-on settings during the initialization procedure.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Don't Reset
        /// VI_TRUE  (1) - Reset Device (Default Value)
        /// 
        /// Notes:
        /// 
        /// (1) If you do not want the instrument reset. Set this control to "Don't Reset" while initializing the instrument.
        /// 
        /// </param>
        public rssgs(string Resource_Name, bool ID_Query, bool Reset_Device)
        {
            System.IntPtr instrumentHandle;
            int pInvokeResult = PInvoke.init(Resource_Name, System.Convert.ToUInt16(ID_Query), System.Convert.ToUInt16(Reset_Device), out instrumentHandle);
            this._handle = new System.Runtime.InteropServices.HandleRef(this, instrumentHandle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            this._disposed = false;
        }

        /// <summary>
        /// Gets the instrument handle.
        /// </summary>
        /// <value>
        /// The value is the IntPtr that represents the handle to the instrument.
        /// </value>
        public System.IntPtr Handle
        {
            get
            {
                return this._handle.Handle;
            }
        }

        /// <summary>
        /// This function sets RF frequency and RF level.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]FREQuency[:CW|FIXed]
        /// [:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]
        /// </summary>
        /// <param name="Frequency">
        /// Sets the RF frequency of the RF output connector.
        /// 
        /// Valid Values:
        /// 1.0e+6 to 12.2e+9
        /// 
        /// Default Value:
        /// 1.0e+6
        /// </param>
        /// <param name="Level">
        /// This control sets the RF signal's power level.
        /// 
        /// Valid Values:
        /// -130.0 to 30.0
        /// 
        /// Default Value:
        /// -10.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequencyAndLevel(double Frequency, double Level)
        {
            int pInvokeResult = PInvoke.SetFrequencyAndLevel(this._handle, Frequency, Level);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function enables and disables special PCI express features.
        /// 
        /// Remote-control command(s):
        /// -
        /// </summary>
        /// <param name="Fast_Enabled">
        /// Activates/deactivates the fast mode.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value: VI_FALSE (0)
        /// 
        /// </param>
        /// <param name="Asynchronous_Enabled">
        /// Activates/deactivates the asynchronous mode.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value: VI_FALSE (0)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int UseFastSettings(bool Fast_Enabled, bool Asynchronous_Enabled)
        {
            int pInvokeResult = PInvoke.UseFastSettings(this._handle, System.Convert.ToUInt16(Fast_Enabled), System.Convert.ToUInt16(Asynchronous_Enabled));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// In fast mode this function sends an empty command to  .
        /// 
        /// Remote-control command(s):
        /// -
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int FastSync()
        {
            int pInvokeResult = PInvoke.FastSync(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the state of the signal output.
        /// 
        /// Remote-control command(s):
        /// :OUTPut[:STATe]
        /// </summary>
        /// <param name="State">
        /// This control sets the state of the signal output.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetRFState(bool State)
        {
            int pInvokeResult = PInvoke.SetRFState(this._handle, System.Convert.ToUInt16(State));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state of the signal output.
        /// 
        /// Remote-control command(s):
        /// :OUTPut[:STATe]?
        /// </summary>
        /// <param name="State">
        /// Displays the state of the signal output.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetRFState(out bool State)
        {
            ushort StateAsUShort;
            int pInvokeResult = PInvoke.GetRFState(this._handle, out StateAsUShort);
            State = System.Convert.ToBoolean(StateAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the number of RF paths.
        /// 
        /// Remote-control command(s):
        /// [:SOURce]:PATH:COUNt?
        /// </summary>
        /// <param name="Paths">
        /// Displays the number of RF paths.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetRFNumberofPaths(out int Paths)
        {
            int pInvokeResult = PInvoke.GetRFNumberofPaths(this._handle, out Paths);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the mode of the attenuator at the RF output (Attenuator MODe).
        /// 
        /// Remote-control command(s):
        /// OUTPut:AMODe AUTO | FIXed
        /// </summary>
        /// <param name="Attenuator_Mode">
        /// This control sets the mode of the attenuator at the RF output (Attenuator MODe).
        /// 
        /// Valid Values:
        /// RSSGS_RF_ATT_MODE_AUTO (0) - Auto
        /// RSSGS_RF_ATT_MODE_FIX  (1) - Fixed
        /// 
        /// Default Value:
        /// RSSGS_RF_ATT_MODE_AUTO (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetRFAttenuatorMode(int Attenuator_Mode)
        {
            int pInvokeResult = PInvoke.SetRFAttenuatorMode(this._handle, Attenuator_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the mode of the attenuator at the RF output (Attenuator MODe).
        /// 
        /// Remote-control command(s):
        /// OUTPut:AMODe?
        /// </summary>
        /// <param name="Attenuator_Mode">
        /// Displays the mode of the attenuator at the RF output (Attenuator MODe).
        /// 
        /// Valid Values:
        /// RSSGS_RF_ATT_MODE_AUTO (0) - Auto
        /// RSSGS_RF_ATT_MODE_FIX  (1) - Fixed
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetRFAttenuatorMode(out int Attenuator_Mode)
        {
            int pInvokeResult = PInvoke.GetRFAttenuatorMode(this._handle, out Attenuator_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the operation mode. NORMal: normal operation. BBBYpass: Base band bypass mode.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]OPMode BBBYpass | NORMal
        /// 
        /// </summary>
        /// <param name="Operation_Mode">
        /// This control sets the operation mode. NORMal: normal operation. BBBYpass: Base band bypass mode.
        /// 
        /// Valid Values:
        /// RSSGS_OPERATION_MODE_NORMAL (0) - Normal
        /// RSSGS_OPERATION_MODE_BBY    (1) - Baseband Bypass
        /// 
        /// Default Value:
        /// RSSGS_OPERATION_MODE_NORMAL (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetOperationMode(int Operation_Mode)
        {
            int pInvokeResult = PInvoke.SetOperationMode(this._handle, Operation_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the operation mode.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]OPMode?
        /// 
        /// </summary>
        /// <param name="Operation_Mode">
        /// Displays the operation mode.
        /// 
        /// Valid Values:
        /// RSSGS_OPERATION_MODE_NORMAL (0) - Normal
        /// RSSGS_OPERATION_MODE_BBY    (1) - Baseband Bypass
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetOperationMode(out int Operation_Mode)
        {
            int pInvokeResult = PInvoke.GetOperationMode(this._handle, out Operation_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the path number of baseband paths.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]BB:PATH:COUNt?
        /// </summary>
        /// <param name="Baseband_Paths">
        /// Displays the path number of baseband paths.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetBasebandPaths(out int Baseband_Paths)
        {
            int pInvokeResult = PInvoke.GetBasebandPaths(this._handle, out Baseband_Paths);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the local oscillator signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        /// [:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        /// </summary>
        /// <param name="Source">
        /// This control sets the source of the local oscillator signal.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// 
        /// Default Value:
        /// RSSGS_LO_SOURCE_INT (0)
        /// </param>
        /// <param name="Output">
        /// This control sets the signal to be connected to the REF output connector.
        /// 
        /// Valid Values:
        /// RSSGS_LO_OUTPUT_REF (0) - REF
        /// RSSGS_LO_OUTPUT_LO  (1) - LO
        /// RSSGS_LO_OUTPUT_OFF (2) - OFF
        /// 
        /// Default Value:
        /// RSSGS_LO_OUTPUT_REF (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureFrequencyLocalOscillator(int Source, int Output)
        {
            int pInvokeResult = PInvoke.ConfigureFrequencyLocalOscillator(this._handle, Source, Output);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the RF frequency of the RF output connector.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]FREQuency[:CW|FIXed]
        /// </summary>
        /// <param name="Frequency">
        /// Sets the RF frequency of the RF output connector.
        /// 
        /// Valid Values:
        /// 1.0e+6 to 12.2e+9
        /// 
        /// Default Value:
        /// 1.0e+6
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequency(double Frequency)
        {
            int pInvokeResult = PInvoke.SetFrequency(this._handle, Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the RF frequency of the RF output connector.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]FREQuency[:CW|FIXed]?
        /// </summary>
        /// <param name="Frequency">
        /// Displays the RF frequency of the RF output connector.
        /// 
        /// Valid Values:
        /// 1.0e+6 to 12.2e+9
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetFrequency(out double Frequency)
        {
            int pInvokeResult = PInvoke.GetFrequency(this._handle, out Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the RF signal's relative phase.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]PHASe
        /// </summary>
        /// <param name="Delta_Phase">
        /// Sets the RF signal's relative phase.
        /// 
        /// Valid Values:
        /// -360.0 to 360.0
        /// 
        /// Default Value:
        /// 0.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequencyDeltaPhase(double Delta_Phase)
        {
            int pInvokeResult = PInvoke.SetFrequencyDeltaPhase(this._handle, Delta_Phase);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the RF signal's relative phase.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]PHASe?
        /// </summary>
        /// <param name="Delta_Phase">
        /// Displays the RF signal's relative phase.
        /// 
        /// Valid Values:
        /// -360.0 to 360.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetFrequencyDeltaPhase(out double Delta_Phase)
        {
            int pInvokeResult = PInvoke.GetFrequencyDeltaPhase(this._handle, out Delta_Phase);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function adopt the phase set with SOURce:PHASe as the current phase.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]PHASe:REFerence
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequencyDeltaPhaseAsCurrent()
        {
            int pInvokeResult = PInvoke.SetFrequencyDeltaPhaseAsCurrent(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the source of the local oscillator signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        /// </summary>
        /// <param name="Source">
        /// This control sets the source of the local oscillator signal.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// 
        /// Default Value:
        /// RSSGS_LO_SOURCE_INT (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequencyLocalOscillatorSource(int Source)
        {
            int pInvokeResult = PInvoke.SetFrequencyLocalOscillatorSource(this._handle, Source);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the source of the local oscillator signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]LOSCillator:SOURce?
        /// 
        /// </summary>
        /// <param name="Source">
        /// Displays the source of the local oscillator signal.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetFrequencyLocalOscillatorSource(out int Source)
        {
            int pInvokeResult = PInvoke.GetFrequencyLocalOscillatorSource(this._handle, out Source);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the signal to be connected to the REF output connector.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        /// </summary>
        /// <param name="Output">
        /// This control sets the signal to be connected to the REF output connector.
        /// 
        /// Valid Values:
        /// RSSGS_LO_OUTPUT_REF (0) - REF
        /// RSSGS_LO_OUTPUT_LO  (1) - LO
        /// RSSGS_LO_OUTPUT_OFF (2) - OFF
        /// 
        /// Default Value:
        /// RSSGS_LO_OUTPUT_REF (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFrequencyLocalOscillatorOutput(int Output)
        {
            int pInvokeResult = PInvoke.SetFrequencyLocalOscillatorOutput(this._handle, Output);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the signal to be connected to the REF output connector.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]CONNector:REFLo:OUTPut?
        /// 
        /// </summary>
        /// <param name="Output">
        /// Displays the signal to be connected to the REF output connector.
        /// 
        /// Valid Values:
        /// RSSGS_LO_OUTPUT_REF (0) - REF
        /// RSSGS_LO_OUTPUT_LO  (1) - LO
        /// RSSGS_LO_OUTPUT_OFF (2) - OFF
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetFrequencyLocalOscillatorOutput(out int Output)
        {
            int pInvokeResult = PInvoke.GetFrequencyLocalOscillatorOutput(this._handle, out Output);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures reference oscillator parameters.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:SOURce EXTernal | INTernal
        /// [:SOURce:]ROSCillator:EXTernal:FREQuency EF10M | EF100M | EF1000M
        /// [:SOURce:]ROSCillator:OUTPut:FREQuency OF10M | OF100M | OF1000M | OFF
        /// [:SOURce:]LOSCillator:SOURce EXTernal | INTernal
        /// [:SOURce:]CONNector:REFLo:OUTPut REF | LO | OFF
        /// </summary>
        /// <param name="Source">
        /// This control sets the reference oscillator signal source.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// 
        /// Default Value:
        /// RSSGS_SOURCE_INT (0)
        /// </param>
        /// <param name="Reference_Frequency">
        /// This control sets the reference output frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        /// RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        /// RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        /// RSSGS_ROSC_REF_FREQ_OFF     (3) - Off
        /// 
        /// Default Value:
        /// RSSGS_ROSC_REF_FREQ_OF10M   (0)
        /// </param>
        /// <param name="External_Reference_Frequency">
        /// This control sets the external reference input frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        /// 
        /// Default Value:
        /// RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0)
        /// </param>
        /// <param name="Local_Oscillator_Source">
        /// This control sets the source of the local oscillator signal.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// 
        /// Default Value:
        /// RSSGS_LO_SOURCE_INT (0)
        /// </param>
        /// <param name="Local_Oscillator_Output">
        /// This control sets the signal to be connected to the REF output connector.
        /// 
        /// Valid Values:
        /// RSSGS_LO_OUTPUT_REF (0) - REF
        /// RSSGS_LO_OUTPUT_LO  (1) - LO
        /// RSSGS_LO_OUTPUT_OFF (2) - OFF
        /// 
        /// Default Value:
        /// RSSGS_LO_OUTPUT_REF (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureReferenceOscillator(int Source, int Reference_Frequency, int External_Reference_Frequency, int Local_Oscillator_Source, int Local_Oscillator_Output)
        {
            int pInvokeResult = PInvoke.ConfigureReferenceOscillator(this._handle, Source, Reference_Frequency, External_Reference_Frequency, Local_Oscillator_Source, Local_Oscillator_Output);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the reference oscillator signal source.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:SOURce EXTernal | INTernal
        /// </summary>
        /// <param name="Source">
        /// This control sets the reference oscillator signal source.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// 
        /// Default Value:
        /// RSSGS_SOURCE_INT (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCSource(int Source)
        {
            int pInvokeResult = PInvoke.SetROSCSource(this._handle, Source);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the reference oscillator signal source.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:SOURce?
        /// 
        /// </summary>
        /// <param name="Source">
        /// Displays the reference oscillator signal source.
        /// 
        /// Valid Values:
        /// RSSGS_SOURCE_INT (0) - Int
        /// RSSGS_SOURCE_EXT (1) - Ext
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCSource(out int Source)
        {
            int pInvokeResult = PInvoke.GetROSCSource(this._handle, out Source);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the reference output frequency.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:OUTPut:FREQuency OF10M | OF100M | OF1000M
        /// </summary>
        /// <param name="Reference_Frequency">
        /// This control sets the reference output frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        /// RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        /// RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        /// 
        /// Default Value:
        /// RSSGS_ROSC_REF_FREQ_OF10M   (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCReferenceOutputFrequency(int Reference_Frequency)
        {
            int pInvokeResult = PInvoke.SetROSCReferenceOutputFrequency(this._handle, Reference_Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the reference output frequency.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:OUTPut:FREQuency?
        /// 
        /// </summary>
        /// <param name="Reference_Frequency">
        /// Displays the reference output frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_REF_FREQ_OF10M   (0) - 10 MHz
        /// RSSGS_ROSC_REF_FREQ_OF100M  (1) - 100 MHz
        /// RSSGS_ROSC_REF_FREQ_OF1000M (2) - 1000 MHz
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCReferenceOutputFrequency(out int Reference_Frequency)
        {
            int pInvokeResult = PInvoke.GetROSCReferenceOutputFrequency(this._handle, out Reference_Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the external reference input frequency.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:EXTernal:FREQuency EF10M | EF100M | EF1000M
        /// </summary>
        /// <param name="External_Reference_Frequency">
        /// This control sets the external reference input frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        /// 
        /// Default Value:
        /// RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCExternalReferenceFrequency(int External_Reference_Frequency)
        {
            int pInvokeResult = PInvoke.SetROSCExternalReferenceFrequency(this._handle, External_Reference_Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the external reference input frequency.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]ROSCillator:EXTernal:FREQuency?
        /// 
        /// </summary>
        /// <param name="External_Reference_Frequency">
        /// Displays the external reference input frequency.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_EXT_REF_FREQ_EF10M   (0) - 10 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF100M  (1) - 100 MHz
        /// RSSGS_ROSC_EXT_REF_FREQ_EF1000M (2) - 1000 MHz
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCExternalReferenceFrequency(out int External_Reference_Frequency)
        {
            int pInvokeResult = PInvoke.GetROSCExternalReferenceFrequency(this._handle, out External_Reference_Frequency);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the external synchronization bandwidth.
        /// 
        /// Remote-control command(s):
        /// :SOUR:ROSC:EXT:FREQ &lt;ExternalSyncBandwidth&gt;
        /// 
        /// </summary>
        /// <param name="Synchronization_Bandwidth">
        /// This control sets the synchronization bandwidth.
        /// 
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE    (0) - 40 Hz
        /// RSSGS_ROSC_EXT_SYNC_BWIDTH_NARROW  (1) - 250 Hz
        /// 
        /// Default Value: RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCExternalSyncBandwidth(int Synchronization_Bandwidth)
        {
            int pInvokeResult = PInvoke.SetROSCExternalSyncBandwidth(this._handle, Synchronization_Bandwidth);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the external synchronization bandwidth.
        /// 
        /// Remote-control command(s):
        /// :SOUR:ROSC:EXT:FREQ?
        /// 
        /// </summary>
        /// <param name="Synchronization_Bandwidth">
        /// Displays the synchronization bandwidth.
        /// 
        /// Valid Values:
        /// RSSGS_ROSC_EXT_SYNC_BWIDTH_WIDE    (0) - 40 Hz
        /// RSSGS_ROSC_EXT_SYNC_BWIDTH_NARROW  (1) - 250 Hz
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCExternalSyncBandwidth(out int Synchronization_Bandwidth)
        {
            int pInvokeResult = PInvoke.GetROSCExternalSyncBandwidth(this._handle, out Synchronization_Bandwidth);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the oscillator calibration value.
        /// 
        /// Remote-control command(s):
        /// :CALibration:ROSCillator[:DATA]
        /// </summary>
        /// <param name="Data">
        /// This control sets the oscillator calibration value.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// 0.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCCalibrationData(double Data)
        {
            int pInvokeResult = PInvoke.SetROSCCalibrationData(this._handle, Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the oscillator calibration value.
        /// 
        /// Remote-control command(s):
        /// :CALibration:ROSCillator[:DATA]?
        /// 
        /// </summary>
        /// <param name="Data">
        /// Displays the oscillator calibration value.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCCalibrationData(out double Data)
        {
            int pInvokeResult = PInvoke.GetROSCCalibrationData(this._handle, out Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency. With STATe ON, the instrument is no longer in the calibrated state.
        /// 
        /// Remote-control command(s):
        /// [SOURce:]ROSCillator[:INTernal]:ADJust[:STATe] ON | OFF
        /// </summary>
        /// <param name="Adjustment_Active">
        /// Activates/deactivates the pulse modulation.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value: VI_FALSE (0)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCAdjustmentActive(bool Adjustment_Active)
        {
            int pInvokeResult = PInvoke.SetROSCAdjustmentActive(this._handle, System.Convert.ToUInt16(Adjustment_Active));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency. With STATe ON, the instrument is no longer in the calibrated state.
        /// 
        /// Remote-control command(s):
        /// [SOURce:]ROSCillator[:INTernal]:ADJust[:STATe]?
        /// </summary>
        /// <param name="Adjustment_Active">
        /// Determines whether the calibrated (OFF) or a user-defined (ON) adjustment value is used for fine adjustment of the frequency.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCAdjustmentActive(out bool Adjustment_Active)
        {
            ushort Adjustment_ActiveAsUShort;
            int pInvokeResult = PInvoke.GetROSCAdjustmentActive(this._handle, out Adjustment_ActiveAsUShort);
            Adjustment_Active = System.Convert.ToBoolean(Adjustment_ActiveAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function specifies the frequency correction value (adjustment value). A detailed definition is given in  section  RF Reference Frequency - Reference Oscillator.
        /// 
        /// Remote-control command(s):
        /// [SOURce:]ROSCillator[:INTernal]:ADJust:VALue
        /// 
        /// </summary>
        /// <param name="Adjustment_Value">
        /// Specifies the frequency correction value (adjustment value).
        /// 
        /// Valid Range: 0 to 4095
        /// 
        /// Default Value: 1400
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetROSCAdjustmentValue(int Adjustment_Value)
        {
            int pInvokeResult = PInvoke.SetROSCAdjustmentValue(this._handle, Adjustment_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the frequency correction value (adjustment value). A detailed definition is given in  section  RF Reference Frequency - Reference Oscillator.
        /// 
        /// Remote-control command(s):
        /// [SOURce:]ROSCillator[:INTernal]:ADJust:VALue?
        /// 
        /// </summary>
        /// <param name="Adjustment_Value">
        /// Returns the frequency correction value (adjustment value).
        /// 
        /// Valid Range: 0 to 4095
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetROSCAdjustmentValue(out int Adjustment_Value)
        {
            int pInvokeResult = PInvoke.GetROSCAdjustmentValue(this._handle, out Adjustment_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the RF signal's power level
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]
        /// </summary>
        /// <param name="Level">
        /// This control sets the RF signal's power level.
        /// 
        /// Valid Values:
        /// -130.0 to 30.0
        /// 
        /// Default Value:
        /// -10.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevel(double Level)
        {
            int pInvokeResult = PInvoke.SetLevel(this._handle, Level);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the level.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:LMODe AUTO | LNOise | LDIStortion
        /// [:SOURce:]POWer:SCHaracteristic AUTO | UNIN | MON | CPH
        /// [:SOURce:]POWer:LIMit[:AMPLitude]
        /// </summary>
        /// <param name="Mode">
        /// This control sets the level mode.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_MODE_AUTO (0) - Normal
        /// RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        /// RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_MODE_AUTO (0)
        /// </param>
        /// <param name="Setting_Characteristic">
        /// This control sets the characteristic for the level setting.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        /// RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        /// RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        /// RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        /// 
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_SETT_CHARACT_AUTO (0)
        /// </param>
        /// <param name="Limit">
        /// This control sets the upper limit of the RF signal power.
        /// 
        /// Valid Values:
        /// -300.0 to 30.0
        /// 
        /// Default Value:
        /// 30.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureLevelSettings(int Mode, int Setting_Characteristic, double Limit)
        {
            int pInvokeResult = PInvoke.ConfigureLevelSettings(this._handle, Mode, Setting_Characteristic, Limit);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the level mode.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:LMODe AUTO | LNOise | LDIStortion
        /// </summary>
        /// <param name="Mode">
        /// This control sets the level mode.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_MODE_AUTO (0) - Normal
        /// RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        /// RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_MODE_AUTO (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevelMode(int Mode)
        {
            int pInvokeResult = PInvoke.SetLevelMode(this._handle, Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the level mode.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:LMODe?
        /// 
        /// </summary>
        /// <param name="Mode">
        /// Displays the level mode.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_MODE_AUTO (0) - Normal
        /// RSSGS_LEVEL_MODE_LNO  (1) - Low Noise
        /// RSSGS_LEVEL_MODE_LDIS (2) - Low Distortion
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevelMode(out int Mode)
        {
            int pInvokeResult = PInvoke.GetLevelMode(this._handle, out Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the characteristic for the level setting.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:SCHaracteristic AUTO | UNIN | MON | CPH
        /// </summary>
        /// <param name="Setting_Characteristic">
        /// This control sets the characteristic for the level setting.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        /// RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        /// RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        /// RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        /// 
        /// 
        /// Default Value: RSSGS_LEVEL_SETT_CHARACT_AUTO (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevelSettingCharacteristic(int Setting_Characteristic)
        {
            int pInvokeResult = PInvoke.SetLevelSettingCharacteristic(this._handle, Setting_Characteristic);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the characteristic for the level setting.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:SCHaracteristic?
        /// 
        /// </summary>
        /// <param name="Setting_Characteristic">
        /// Displays the characteristic for the level setting.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_SETT_CHARACT_AUTO (0) - Auto
        /// RSSGS_LEVEL_SETT_CHARACT_UNIN (1) - Uninterrupted Level Setting
        /// RSSGS_LEVEL_SETT_CHARACT_MON  (2) - Strictly Monotone
        /// RSSGS_LEVEL_SETT_CHARACT_CWSW (3) - Constant-VSWR
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevelSettingCharacteristic(out int Setting_Characteristic)
        {
            int pInvokeResult = PInvoke.GetLevelSettingCharacteristic(this._handle, out Setting_Characteristic);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the RF signal's power level
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer[:LEVel][:IMMediate][:AMPLitude]?
        /// 
        /// </summary>
        /// <param name="Level">
        /// Displays the RF signal's power level.
        /// 
        /// Valid Values:
        /// -130.0 to 30.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevel(out double Level)
        {
            int pInvokeResult = PInvoke.GetLevel(this._handle, out Level);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the upper limit of the RF signal power.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:LIMit[:AMPLitude]
        /// </summary>
        /// <param name="Limit">
        /// This control sets the upper limit of the RF signal power.
        /// 
        /// Valid Values:
        /// -300.0 to 30.0
        /// 
        /// Default Value:
        /// 30.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevelLimit(double Limit)
        {
            int pInvokeResult = PInvoke.SetLevelLimit(this._handle, Limit);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the upper limit of the RF signal power.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:LIMit[:AMPLitude]?
        /// 
        /// </summary>
        /// <param name="Limit">
        /// Displays the upper limit of the RF signal power.
        /// 
        /// Valid Values:
        /// -300.0 to 30.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevelLimit(out double Limit)
        {
            int pInvokeResult = PInvoke.GetLevelLimit(this._handle, out Limit);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the state which the RF output assumes when the instrument is switched on.
        /// 
        /// Remote-control command(s):
        /// :OUTPut[:STATe]:PON UNCHanged | OFF
        /// </summary>
        /// <param name="Power_On_State">
        /// This control sets the state which the RF output assumes when the instrument is switched on.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_POW_ON_OFF  (0) - RF Off
        /// RSSGS_LEVEL_POW_ON_UNCH (1) - Previous Setting
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_POW_ON_UNCH (1)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevelPowerOnState(int Power_On_State)
        {
            int pInvokeResult = PInvoke.SetLevelPowerOnState(this._handle, Power_On_State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state which the RF output assumes when the instrument is switched on.
        /// 
        /// Remote-control command(s):
        /// :OUTPut[:STATe]:PON?
        /// 
        /// </summary>
        /// <param name="Power_On_State">
        /// Displays the state which the RF output assumes when the instrument is switched on.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_POW_ON_OFF  (0) - RF Off
        /// RSSGS_LEVEL_POW_ON_UNCH (1) - Previous Setting
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevelPowerOnState(out int Power_On_State)
        {
            int pInvokeResult = PInvoke.GetLevelPowerOnState(this._handle, out Power_On_State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the automatic level control.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ALC[:STATe] ON | 1  | ONTable | OFFTable
        /// </summary>
        /// <param name="State">
        /// This control sets automatic level control.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_ALC_STATE_ONT  (0) - Table &amp; On
        /// RSSGS_LEVEL_ALC_STATE_ON   (1) - On
        /// RSSGS_LEVEL_ALC_STATE_OFFT (2) - Off (Table) 
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_ALC_STATE_ONT  (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetLevelALCState(int State)
        {
            int pInvokeResult = PInvoke.SetLevelALCState(this._handle, State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the automatic level control.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ALC[:STATe]?
        /// 
        /// </summary>
        /// <param name="State">
        /// Displays the automatic level control.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_ALC_STATE_ONT  (0) - Table &amp; On
        /// RSSGS_LEVEL_ALC_STATE_ON   (1) - On
        /// RSSGS_LEVEL_ALC_STATE_OFFT (2) - Off (Table)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetLevelALCState(out int State)
        {
            int pInvokeResult = PInvoke.GetLevelALCState(this._handle, out State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function activate level control for correction purposes.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ALC:SONCe
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ReadjustLevelALC()
        {
            int pInvokeResult = PInvoke.ReadjustLevelALC(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the state which the attenuator is to assume after the instrument is switched on.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ATTenuation:RFOFf:MODE FIXed | MAX
        /// </summary>
        /// <param name="Mode">
        /// This control sets the state which the attenuator is to assume after the instrument is switched on.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_ATT_ON_FIX (0) - Fixed
        /// RSSGS_LEVEL_ATT_ON_MAX (1) - Maximum
        /// 
        /// Default Value:
        /// RSSGS_LEVEL_ATT_ON_MAX (1)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetAttenuatorModeAfterOn(int Mode)
        {
            int pInvokeResult = PInvoke.SetAttenuatorModeAfterOn(this._handle, Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state which the attenuator is to assume after the instrument is switched on.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ATTenuation:RFOFf:MODE?
        /// 
        /// </summary>
        /// <param name="Mode">
        /// Displays the state which the attenuator is to assume after the instrument is switched on.
        /// 
        /// Valid Values:
        /// RSSGS_LEVEL_ATT_ON_FIX (0) - Fixed
        /// RSSGS_LEVEL_ATT_ON_MAX (1) - Maximum
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetAttenuatorModeAfterOn(out int Mode)
        {
            int pInvokeResult = PInvoke.GetAttenuatorModeAfterOn(this._handle, out Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the switch-over offset value of the attenuator.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ATTenuation:SOVer[:OFFSet]
        /// </summary>
        /// <param name="Offset">
        /// This control sets the switch-over offset value of the attenuator.
        /// 
        /// Valid Values:
        /// -10.0 to 10.0
        /// 
        /// Default Value:
        /// 0.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetAttenuatorSwitchOverOffset(double Offset)
        {
            int pInvokeResult = PInvoke.SetAttenuatorSwitchOverOffset(this._handle, Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the switch-over offset value of the attenuator.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]POWer:ATTenuation:SOVer[:OFFSet]?
        /// 
        /// </summary>
        /// <param name="Offset">
        /// Displays the switch-over offset value of the attenuator.
        /// 
        /// Valid Values:
        /// -10.0 to 10.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetAttenuatorSwitchOverOffset(out double Offset)
        {
            int pInvokeResult = PInvoke.GetAttenuatorSwitchOverOffset(this._handle, out Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the minimum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        /// 
        /// Remote-control command(s):
        /// OUTPut:AFIXed:RANGe:LOWer?
        /// </summary>
        /// <param name="Attenuator_Lower_Range">
        /// Returns the minimum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetAttenuatorLowerRange(out double Attenuator_Lower_Range)
        {
            int pInvokeResult = PInvoke.GetAttenuatorLowerRange(this._handle, out Attenuator_Lower_Range);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the maximum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        /// 
        /// Remote-control command(s):
        /// OUTPut:AFIXed:RANGe:UPPer?
        /// </summary>
        /// <param name="Attenuator_Upper_Range">
        /// Returns the maximum level which can be set without the attenuator being adjusted (Attenuator FIXed).
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetAttenuatorUpperRange(out double Attenuator_Upper_Range)
        {
            int pInvokeResult = PInvoke.GetAttenuatorUpperRange(this._handle, out Attenuator_Upper_Range);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the IQ modulator.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]MODulator:STATe
        /// [:SOURce:]BB:IMPairment:IQWBand[:STATe]
        /// </summary>
        /// <param name="IQ_Modulator_State">
        /// This control sets the state of the IQ modulator.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <param name="IQ_Wideband">
        /// This control sets optimized settings for wideband modulation signals.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureIQ(bool IQ_Modulator_State, bool IQ_Wideband)
        {
            int pInvokeResult = PInvoke.ConfigureIQ(this._handle, System.Convert.ToUInt16(IQ_Modulator_State), System.Convert.ToUInt16(IQ_Wideband));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the IQ Impairments.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:STATe
        /// [:SOURce:]IQ:IMPairment:LEAKage:I
        /// [:SOURce:]IQ:IMPairment:LEAKage:Q
        /// [:SOURce:]IQ:IMPairment:IQRatio
        /// [:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]
        /// </summary>
        /// <param name="State">
        /// This control sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <param name="I_Offset">
        /// This control sets the carrier offset for the I-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <param name="Q_Offset">
        /// This control sets the carrier offset for the Q-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <param name="Gain_Imbalance">
        /// This control sets the ratio of I modulation to Q modulation (gain imbalance).
        /// 
        /// Valid Values:
        /// -1.000 to 1.000
        /// 
        /// Default Value:
        /// 0.000
        /// </param>
        /// <param name="Quadrature_Offset">
        /// This control sets the quadrature offset for the digital I/Q signal.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureIQImpairments(bool State, double I_Offset, double Q_Offset, double Gain_Imbalance, double Quadrature_Offset)
        {
            int pInvokeResult = PInvoke.ConfigureIQImpairments(this._handle, System.Convert.ToUInt16(State), I_Offset, Q_Offset, Gain_Imbalance, Quadrature_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the state of the IQ modulator.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]MODulator:STATe
        /// </summary>
        /// <param name="IQ_Modulator_State">
        /// This control sets the state of the IQ modulator.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQModulatorState(bool IQ_Modulator_State)
        {
            int pInvokeResult = PInvoke.SetIQModulatorState(this._handle, System.Convert.ToUInt16(IQ_Modulator_State));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state of the IQ modulator.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]MODulator:STATe?
        /// </summary>
        /// <param name="IQ_Modulator_State">
        /// Displays the state of the IQ modulator.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQModulatorState(out bool IQ_Modulator_State)
        {
            ushort IQ_Modulator_StateAsUShort;
            int pInvokeResult = PInvoke.GetIQModulatorState(this._handle, out IQ_Modulator_StateAsUShort);
            IQ_Modulator_State = System.Convert.ToBoolean(IQ_Modulator_StateAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:STATe
        /// </summary>
        /// <param name="State">
        /// This control sets the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQImpairmentsState(bool State)
        {
            int pInvokeResult = PInvoke.SetIQImpairmentsState(this._handle, System.Convert.ToUInt16(State));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:STATe?
        /// </summary>
        /// <param name="State">
        /// Displays the impairment or correction values LEAKage, QUADrature and IQRatio for the digital baseband signal.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQImpairmentsState(out bool State)
        {
            ushort StateAsUShort;
            int pInvokeResult = PInvoke.GetIQImpairmentsState(this._handle, out StateAsUShort);
            State = System.Convert.ToBoolean(StateAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the carrier offset for the I-channel of the I/Q modulation.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:LEAKage:I
        /// </summary>
        /// <param name="I_Offset">
        /// This control sets the carrier offset for the I-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQImpairmentsIOffset(double I_Offset)
        {
            int pInvokeResult = PInvoke.SetIQImpairmentsIOffset(this._handle, I_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the carrier offset for the I-channel of the I/Q modulation.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:LEAKage:I?
        /// </summary>
        /// <param name="I_Offset">
        /// Displays the carrier offset for the I-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQImpairmentsIOffset(out double I_Offset)
        {
            int pInvokeResult = PInvoke.GetIQImpairmentsIOffset(this._handle, out I_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the carrier offset for the Q-channel of the I/Q modulation.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:LEAKage:Q
        /// </summary>
        /// <param name="Q_Offset">
        /// This control sets the carrier offset for the Q-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQImpairmentsQOffset(double Q_Offset)
        {
            int pInvokeResult = PInvoke.SetIQImpairmentsQOffset(this._handle, Q_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the carrier offset for the Q-channel of the I/Q modulation.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:LEAKage:Q?
        /// </summary>
        /// <param name="Q_Offset">
        /// Displays the carrier offset for the Q-channel of the I/Q modulation.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQImpairmentsQOffset(out double Q_Offset)
        {
            int pInvokeResult = PInvoke.GetIQImpairmentsQOffset(this._handle, out Q_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the ratio of I modulation to Q modulation (gain imbalance).
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:IQRatio
        /// </summary>
        /// <param name="Gain_Imbalance">
        /// This control sets the ratio of I modulation to Q modulation (gain imbalance).
        /// 
        /// Valid Values:
        /// -1.000 to 1.000
        /// 
        /// Default Value:
        /// 0.000
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQImpairmentsGainImbalance(double Gain_Imbalance)
        {
            int pInvokeResult = PInvoke.SetIQImpairmentsGainImbalance(this._handle, Gain_Imbalance);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the ratio of I modulation to Q modulation (gain imbalance).
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:IQRatio?
        /// </summary>
        /// <param name="Gain_Imbalance">
        /// Displays the ratio of I modulation to Q modulation (gain imbalance).
        /// 
        /// Valid Values:
        /// -1.000 to 1.000
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQImpairmentsGainImbalance(out double Gain_Imbalance)
        {
            int pInvokeResult = PInvoke.GetIQImpairmentsGainImbalance(this._handle, out Gain_Imbalance);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the quadrature offset for the digital I/Q signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]
        /// </summary>
        /// <param name="Quadrature_Offset">
        /// This control sets the quadrature offset for the digital I/Q signal.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// 
        /// Default Value:
        /// 0.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQImpairmentsQuadratureOffset(double Quadrature_Offset)
        {
            int pInvokeResult = PInvoke.SetIQImpairmentsQuadratureOffset(this._handle, Quadrature_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the quadrature offset for the digital I/Q signal.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:QUADrature[:ANGLe]?
        /// </summary>
        /// <param name="Quadrature_Offset">
        /// Displays the quadrature offset for the digital I/Q signal.
        /// 
        /// Valid Values:
        /// -10.00 to 10.00
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQImpairmentsQuadratureOffset(out double Quadrature_Offset)
        {
            int pInvokeResult = PInvoke.GetIQImpairmentsQuadratureOffset(this._handle, out Quadrature_Offset);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets optimized settings for wideband modulation signals.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:IQWBand[:STATe]
        /// </summary>
        /// <param name="IQ_Wideband">
        /// This control sets optimized settings for wideband modulation signals.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetIQWideband(bool IQ_Wideband)
        {
            int pInvokeResult = PInvoke.SetIQWideband(this._handle, System.Convert.ToUInt16(IQ_Wideband));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries optimized settings for wideband modulation signals.
        /// 
        /// Remote-control command(s):
        /// [:SOURce:]IQ:IMPairment:IQWBand[:STATe]?
        /// </summary>
        /// <param name="IQ_Wideband">
        /// Displays optimized settings for wideband modulation signals.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetIQWideband(out bool IQ_Wideband)
        {
            ushort IQ_WidebandAsUShort;
            int pInvokeResult = PInvoke.GetIQWideband(this._handle, out IQ_WidebandAsUShort);
            IQ_Wideband = System.Convert.ToBoolean(IQ_WidebandAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the SGU extension module.
        /// 
        /// Remote-control command(s):
        /// :EXTension:ACTive:STATe
        /// :EXTension:REMote:CHANnel LAN | USB | PCIE | SOCKet
        /// :EXTension:REMote:LAN:NAME
        /// :EXTension:SERial
        /// </summary>
        /// <param name="State">
        /// This control sets the state of the SGU extension module.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <param name="Hardware_Channel">
        /// This control sets the channel of the SGU extension device.
        /// 
        /// Valid Values:
        /// RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        /// RSSGS_SGU_HW_CHANN_USB  (1) - USB
        /// RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        /// RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        /// 
        /// Default Value:
        /// RSSGS_SGU_HW_CHANN_LAN  (0)
        /// </param>
        /// <param name="Instrument_Name">
        /// This control sets the LAN IP address / instrument name of the SGU extension device.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// ""
        /// 
        /// Note(s):
        /// This control is valid only for Hardware Channel LAN and Socket.
        /// </param>
        /// <param name="Serial_Number">
        /// This control sets the Serial number of the SGU extension  (for USB and PCIe).
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// 100001
        /// 
        /// Note(s):
        /// This control is valid only for Hardware Channel USB and PCIe.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureExtension(bool State, int Hardware_Channel, string Instrument_Name, int Serial_Number)
        {
            int pInvokeResult = PInvoke.ConfigureExtension(this._handle, System.Convert.ToUInt16(State), Hardware_Channel, Instrument_Name, Serial_Number);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the state of the SGU extension module.
        /// 
        /// Remote-control command(s):
        /// :EXTension:ACTive:STATe
        /// </summary>
        /// <param name="State">
        /// This control sets the state of the SGU extension module.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value:
        /// VI_FALSE (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetExtensionState(bool State)
        {
            int pInvokeResult = PInvoke.SetExtensionState(this._handle, System.Convert.ToUInt16(State));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state of the SGU extension module.
        /// 
        /// Remote-control command(s):
        /// :EXTension:ACTive:STATe?
        /// </summary>
        /// <param name="State">
        /// Displays the state of the SGU extension module.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionState(out bool State)
        {
            ushort StateAsUShort;
            int pInvokeResult = PInvoke.GetExtensionState(this._handle, out StateAsUShort);
            State = System.Convert.ToBoolean(StateAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the channel of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:REMote:CHANnel LAN | USB | PCIE | SOCKet
        /// </summary>
        /// <param name="Hardware_Channel">
        /// This control sets the channel of the SGU extension device.
        /// 
        /// Valid Values:
        /// RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        /// RSSGS_SGU_HW_CHANN_USB  (1) - USB
        /// RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        /// RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        /// 
        /// Default Value:
        /// RSSGS_SGU_HW_CHANN_LAN  (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetExtensionHardwareChannel(int Hardware_Channel)
        {
            int pInvokeResult = PInvoke.SetExtensionHardwareChannel(this._handle, Hardware_Channel);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the channel of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:REMote:CHANnel?
        /// </summary>
        /// <param name="Hardware_Channel">
        /// Displays the channel of the SGU extension device.
        /// 
        /// Valid Values:
        /// RSSGS_SGU_HW_CHANN_LAN  (0) - LAN
        /// RSSGS_SGU_HW_CHANN_USB  (1) - USB
        /// RSSGS_SGU_HW_CHANN_PCIE (2) - PCIe
        /// RSSGS_SGU_HW_CHANN_SOCK (3) - Socket
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionHardwareChannel(out int Hardware_Channel)
        {
            int pInvokeResult = PInvoke.GetExtensionHardwareChannel(this._handle, out Hardware_Channel);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the LAN IP address / instrument name of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:REMote:LAN:NAME
        /// </summary>
        /// <param name="Instrument_Name">
        /// This control sets the LAN IP address / instrument name of the SGU extension device.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// ""
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetExtensionInstrumentName(string Instrument_Name)
        {
            int pInvokeResult = PInvoke.SetExtensionInstrumentName(this._handle, Instrument_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the LAN IP address / instrument name of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:REMote:LAN:NAME?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Instrument_Name">
        /// Displays the LAN IP address / instrument name of the SGU extension device.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionInstrumentName(int Array_Size, System.Text.StringBuilder Instrument_Name)
        {
            int pInvokeResult = PInvoke.GetExtensionInstrumentName(this._handle, Array_Size, Instrument_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the Serial number of the SGU extension  (for USB and PCIe).
        /// 
        /// Remote-control command(s):
        /// :EXTension:SERial
        /// </summary>
        /// <param name="Serial_Number">
        /// This control sets the Serial number of the SGU extension  (for USB and PCIe).
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// 100001
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetExtensionSerialNumber(int Serial_Number)
        {
            int pInvokeResult = PInvoke.SetExtensionSerialNumber(this._handle, Serial_Number);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the Serial number of the SGU extension  (for USB and PCIe).
        /// 
        /// Remote-control command(s):
        /// :EXTension:SERial?
        /// </summary>
        /// <param name="Serial_Number">
        /// Displays the Serial number of the SGU extension  (for USB and PCIe).
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionSerialNumber(out int Serial_Number)
        {
            int pInvokeResult = PInvoke.GetExtensionSerialNumber(this._handle, out Serial_Number);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the state of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:REMote:STATe?
        /// </summary>
        /// <param name="Remote_State">
        /// Displays the state of the SGU extension device.
        /// 
        /// Valid Values:
        /// 0 - not connected
        /// 1 - connected
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionRemoteState(out int Remote_State)
        {
            int pInvokeResult = PInvoke.GetExtensionRemoteState(this._handle, out Remote_State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the busy state of the SGU extension device.
        /// 
        /// Remote-control command(s):
        /// :EXTension:BUSY:STATe?
        /// </summary>
        /// <param name="Busy_State">
        /// Displays the busy state of the SGU extension device.
        /// 
        /// Valid Values:
        /// 0 - not bussy
        /// 1 - bussy
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetExtensionBusyState(out int Busy_State)
        {
            int pInvokeResult = PInvoke.GetExtensionBusyState(this._handle, out Busy_State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function pass a lock request id which uniquely identifies the controller to the instrument.
        /// 
        /// Remote-control command(s):
        /// LOCK?
        /// </summary>
        /// <param name="Lock_ID">
        /// This control uniquely identifies the controller to the instrument.
        /// 
        /// Valid Values: 
        /// Not Checked
        /// 
        /// Default Value:
        /// 0
        /// 
        /// </param>
        /// <param name="Result">
        /// Pass a lock request id which uniquely identifies the controller to the instrument.
        /// 
        /// Valid Values:
        /// 0 - Request refused
        /// 1 - Request granted
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int LockInstrument(int Lock_ID, out int Result)
        {
            int pInvokeResult = PInvoke.LockInstrument(this._handle, Lock_ID, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function unlock device.
        /// 
        /// Remote-control command(s):
        /// UNLock
        /// </summary>
        /// <param name="Lock_ID">
        /// This control uniquely identifies the controller to the instrument.
        /// 
        /// Valid Values: 
        /// Not Checked
        /// 
        /// Default Value:
        /// 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int UnlockInstrument(int Lock_ID)
        {
            int pInvokeResult = PInvoke.UnlockInstrument(this._handle, Lock_ID);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function perform all internal adjustments.
        /// 
        /// Note:
        /// 
        /// If the calibration fails, this function returns an error code.
        /// 
        /// Remote-control command(s):
        /// CALibration:ALL?
        /// *OPC?
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 180000 ms
        /// 
        /// </param>
        /// <param name="Result">
        /// Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int CALibrationAll(int Timeout, out int Result)
        {
            int pInvokeResult = PInvoke.CALibrationAll(this._handle, Timeout, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function perform internal level adjustment.
        /// 
        /// Note:
        /// If the calibration fails, this function returns an error code.
        /// 
        /// 
        /// Remote-control command(s):
        /// CALibration:LEVel[:MEASure]?
        /// *OPC?
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 180000 ms
        /// 
        /// </param>
        /// <param name="Result">
        /// Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int CALibrationLevel(int Timeout, out int Result)
        {
            int pInvokeResult = PInvoke.CALibrationLevel(this._handle, Timeout, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function performs all adjustments which affect the frequency.
        /// 
        /// Note:
        /// If the calibration fails, this function returns an error code.
        /// 
        /// Remote-control command(s):
        /// CAL:FREQ?
        /// *OPC?
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 180000 ms
        /// 
        /// </param>
        /// <param name="Result">
        /// Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int CALibrationSynthesis(int Timeout, out int Result)
        {
            int pInvokeResult = PInvoke.CALibrationSynthesis(this._handle, Timeout, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function starts the adjustment for the I/Q modulator for the entire frequency range. The I/Q modulator is adjusted with respect to carrier leakage, I/Q imbalance and quadrature.
        /// 
        /// Note:
        /// If the calibration fails, this function returns an error code.
        /// 
        /// Remote-control command(s):
        /// CALibration:MODulator?
        /// *OPC?
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 180000 ms
        /// 
        /// </param>
        /// <param name="Result">
        /// Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int CALibrationIQModulator(int Timeout, out int Result)
        {
            int pInvokeResult = PInvoke.CALibrationIQModulator(this._handle, Timeout, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function starts the adjustment for the I/Q modulator for the current frequency. The I/Q modulator is adjusted with respect to carrier leakage, I/Q imbalance and quadrature.
        /// 
        /// Remote-control command(s):
        /// CALibration:MODulator:CFRequency?
        /// *OPC?
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the calibration routine to be finished and have obtained calibration result. If the length of time required for calibration exceeds the timeout value, then the function will return with a timeout error and the instrument will continue with calibration.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 180000 ms
        /// 
        /// </param>
        /// <param name="Result">
        /// Returns result of the adjustment. The response "0" indicates error-free adjustment, and the response "1" means that an error occurred during adjustment.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int CALibrationIQModulatorForCurrentFrequency(int Timeout, out int Result)
        {
            int pInvokeResult = PInvoke.CALibrationIQModulatorForCurrentFrequency(this._handle, Timeout, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function gets network settings from system.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:GET
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkSystemSettings()
        {
            int pInvokeResult = PInvoke.GetNetworkSystemSettings(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the MAC Address.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:MACaddress?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="MAC_Address">
        /// Displays the MAC Address.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkMACAddress(int Array_Size, System.Text.StringBuilder MAC_Address)
        {
            int pInvokeResult = PInvoke.GetNetworkMACAddress(this._handle, Array_Size, MAC_Address);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function configures the IP Address.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:IPADdress:MODE STATic | AUTO
        /// :SYSTem:COMMunicate:NETWork:IPADdress
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway
        /// </summary>
        /// <param name="Address_Mode">
        /// This control sets the IP Address Mode.
        /// 
        /// Valid Values:
        /// RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        /// RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        /// 
        /// Default Value:
        /// RSSGS_IP_ADDRESS_MODE_AUTO (0)
        /// </param>
        /// <param name="IP_Address">
        /// This control sets the IP Address.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <param name="Subnet_Mask">
        /// This control sets the Subnet Mask.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <param name="Default_Gateway">
        /// This control sets the Default Gateway.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ConfigureNetworkIP(int Address_Mode, string IP_Address, string Subnet_Mask, string Default_Gateway)
        {
            int pInvokeResult = PInvoke.ConfigureNetworkIP(this._handle, Address_Mode, IP_Address, Subnet_Mask, Default_Gateway);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the resource string.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:NETWork:RESource?
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Resource'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Resource">
        /// This control displays the resource string.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkResource(uint Array_Size, System.Text.StringBuilder Resource)
        {
            int pInvokeResult = PInvoke.GetNetworkResource(this._handle, Array_Size, Resource);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the network configuration state.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:NETWork:STATus?
        /// </summary>
        /// <param name="Configuration">
        /// This control displays the network configuration state.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkConfigurationState(out bool Configuration)
        {
            ushort ConfigurationAsUShort;
            int pInvokeResult = PInvoke.GetNetworkConfigurationState(this._handle, out ConfigurationAsUShort);
            Configuration = System.Convert.ToBoolean(ConfigurationAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the Hostname of the network.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:COMMon]:HOSTname
        /// </summary>
        /// <param name="Hostname">
        /// This control sets the Hostname of the network.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "Undefined"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetNetworkCommonHostname(string Hostname)
        {
            int pInvokeResult = PInvoke.SetNetworkCommonHostname(this._handle, Hostname);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the Hostname of the network.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:COMMon]:HOSTname?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Hostname">
        /// Displays the Hostname of the network.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkCommonHostname(int Array_Size, System.Text.StringBuilder Hostname)
        {
            int pInvokeResult = PInvoke.GetNetworkCommonHostname(this._handle, Array_Size, Hostname);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the IP Address Mode.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:IPADdress:MODE STATic | AUTO
        /// </summary>
        /// <param name="Address_Mode">
        /// This control sets the IP Address Mode.
        /// 
        /// Valid Values:
        /// RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        /// RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        /// 
        /// Default Value:
        /// RSSGS_IP_ADDRESS_MODE_AUTO (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetNetworkIPAddressMode(int Address_Mode)
        {
            int pInvokeResult = PInvoke.SetNetworkIPAddressMode(this._handle, Address_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the IP Address Mode.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:IPADdress:MODE?
        /// </summary>
        /// <param name="Address_Mode">
        /// Displays the IP Address Mode.
        /// 
        /// Valid Values:
        /// RSSGS_IP_ADDRESS_MODE_AUTO (0) - Auto (DHCP)
        /// RSSGS_IP_ADDRESS_MODE_STAT (1) - Static
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkIPAddressMode(out int Address_Mode)
        {
            int pInvokeResult = PInvoke.GetNetworkIPAddressMode(this._handle, out Address_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the IP Adrress.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:IPADdress
        /// </summary>
        /// <param name="IP_Address">
        /// This control sets the IP Address.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetNetworkIPAddress(string IP_Address)
        {
            int pInvokeResult = PInvoke.SetNetworkIPAddress(this._handle, IP_Address);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the IP Adrress.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork:IPADdress?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="IP_Address">
        /// Displays the IP Address.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkIPAddress(int Array_Size, System.Text.StringBuilder IP_Address)
        {
            int pInvokeResult = PInvoke.GetNetworkIPAddress(this._handle, Array_Size, IP_Address);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the Subnet Mask.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK
        /// </summary>
        /// <param name="Subnet_Mask">
        /// This control sets the Subnet Mask.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetNetworkIPSubnetMask(string Subnet_Mask)
        {
            int pInvokeResult = PInvoke.SetNetworkIPSubnetMask(this._handle, Subnet_Mask);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the Subnet Mask.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:SUBNet:MASK?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Subnet_Mask">
        /// Displays the Subnet Mask.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkIPSubnetMask(int Array_Size, System.Text.StringBuilder Subnet_Mask)
        {
            int pInvokeResult = PInvoke.GetNetworkIPSubnetMask(this._handle, Array_Size, Subnet_Mask);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the Default Gateway.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway
        /// </summary>
        /// <param name="Default_Gateway">
        /// This control sets the Default Gateway.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// "0.0.0.0"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetNetworkIPDefaultGateway(string Default_Gateway)
        {
            int pInvokeResult = PInvoke.SetNetworkIPDefaultGateway(this._handle, Default_Gateway);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the Default Gateway.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:COMMunicate:NETWork[:IPADdress]:GATeway?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Default_Gateway">
        /// Displays the Default Gateway.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetNetworkIPDefaultGateway(int Array_Size, System.Text.StringBuilder Default_Gateway)
        {
            int pInvokeResult = PInvoke.GetNetworkIPDefaultGateway(this._handle, Array_Size, Default_Gateway);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function accepts the IP Address Settings.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:NETWork:IPADdress:SET
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int AcceptNetworkIPSettings()
        {
            int pInvokeResult = PInvoke.AcceptNetworkIPSettings(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the remote control operation mode.
        /// 
        /// Remote-control command(s):
        /// :REMote:OPMode EXTension | STDalone
        /// </summary>
        /// <param name="Operation_Mode">
        /// This control sets the remote control operation mode.
        /// 
        /// Valid Values:
        /// RSSGS_REMOTE_OPER_MODE_EXT (0) - Extension
        /// RSSGS_REMOTE_OPER_MODE_STD (1) - Stand Alone 
        /// 
        /// Default Value:
        /// RSSGS_REMOTE_OPER_MODE_EXT (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetRemoteOperationMode(int Operation_Mode)
        {
            int pInvokeResult = PInvoke.SetRemoteOperationMode(this._handle, Operation_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the remote control operation mode.
        /// 
        /// Remote-control command(s):
        /// :REMote:OPMode?
        /// 
        /// </summary>
        /// <param name="Operation_Mode">
        /// Displays the remote control operation mode.
        /// 
        /// Valid Values:
        /// RSSGS_REMOTE_OPER_MODE_EXT (0) - Extension
        /// RSSGS_REMOTE_OPER_MODE_STD (1) - Stand Alone
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetRemoteOperationMode(out int Operation_Mode)
        {
            int pInvokeResult = PInvoke.GetRemoteOperationMode(this._handle, out Operation_Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// CLEAR STATUS sets the status byte (STB), the standard event register (ESR), and the EVENt part of the QUEStionable and OPERation register to zero. The function does not change the enable and transition parts of the registers. It deletes the output buffer.
        /// 
        /// Remote-control command(s):
        /// *CLS
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ClearStatus()
        {
            int pInvokeResult = PInvoke.ClearStatus(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// EVENT STATUS ENABLE sets the event status enable register to the specified value. The *ESE? query command returns the content of the event status enable register in decimal form.
        /// 
        /// Remote-control command(s):
        /// *ESE
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// EVENT STATUS ENABLE sets the event status enable register to the specified value.
        /// 
        /// Valid Range: 0 to 255
        /// 
        /// Default Value: 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int EventStatusEnable(int Register_Value)
        {
            int pInvokeResult = PInvoke.EventStatusEnable(this._handle, Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// STANDARD EVENT STATUS QUERY returns the content of the event status register in decimal form (0...255) and then sets the register to zero.
        /// 
        /// Remote-control command(s):
        /// *ESR?
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Returns the content of the event status register in decimal form (0...255).
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int EventStatusQuery(out int Register_Value)
        {
            int pInvokeResult = PInvoke.EventStatusQuery(this._handle, out Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// IDENTIFICATION QUERY queries the instrument identification. The instrument type, serial number and firmware version are returned.
        /// 
        /// Example:
        /// 
        /// "Rohde&amp;Schwarz,SMB100A,1141.2005k02/123456,1.00.0.0 (Release)"
        /// 
        /// Remote-control command(s):
        /// *IDN?
        /// 
        /// </summary>
        /// <param name="Instrument_Identification">
        /// Returns the instrument identification string.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 256 elements ViChar[256].
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int IdentificationQuery(System.Text.StringBuilder Instrument_Identification)
        {
            int pInvokeResult = PInvoke.IdentificationQuery(this._handle, Instrument_Identification);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// INDIVIDUAL STATUS QUERY returns the content of the IST flag in decimal form (0 | 1). The IST flag is the status bit which is sent during a parallel poll.
        /// 
        /// Remote-control command(s):
        /// *IST?
        /// 
        /// </summary>
        /// <param name="IST_Flag">
        /// Returns the content of the IST flag in decimal form (0 | 1).
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int IndividualStatusQuery(out int IST_Flag)
        {
            int pInvokeResult = PInvoke.IndividualStatusQuery(this._handle, out IST_Flag);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// OPERATION COMPLETE sets bit 0 in the event status register when all previous commands have been processed. This bit can be used to trigger a service request.
        /// 
        /// Remote-control command(s):
        /// *OPC
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int OperationComplete()
        {
            int pInvokeResult = PInvoke.OperationComplete(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// OPERATION COMPLETE QUERY returns a 1 when all previous commands have been processed. It is important to ensure that the timeout set at the IEC/IEEE bus is long enough.
        /// 
        /// Remote-control command(s):
        /// *OPC?
        /// 
        /// </summary>
        /// <param name="OPC_State">
        /// Returns a 1 when all previous commands have been processed.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int OperationCompleteQuery(out int OPC_State)
        {
            int pInvokeResult = PInvoke.OperationCompleteQuery(this._handle, out OPC_State);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// OPTION IDENTIFICATION QUERY queries the options configured in the instrument and returns a list of the installed options. The options are separated by commas. 
        /// 
        /// Remote-control command(s):
        /// *OPT?
        /// 
        /// </summary>
        /// <param name="Option_Identification">
        /// Returns a list of the installed options.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 1024 elements ViChar[1024].
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int OptionIdentificationQuery(System.Text.StringBuilder Option_Identification)
        {
            int pInvokeResult = PInvoke.OptionIdentificationQuery(this._handle, Option_Identification);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// PARALLEL POLL REGISTER ENABLE sets the parallel poll enable register to the specified value. The *PRE? query command returns the content of the parallel poll enable register in decimal form.
        /// 
        /// Remote-control command(s):
        /// *PRE
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Sets the parallel poll enable register to the specified value.
        /// 
        /// Valid Range: 0 to 655
        /// 
        /// Default Value: 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ParallelPollRegisterEnable(int Register_Value)
        {
            int pInvokeResult = PInvoke.ParallelPollRegisterEnable(this._handle, Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// PARALLEL POLL REGISTER QUERY returns the content of the parallel poll enable register in decimal form.
        /// 
        /// Remote-control command(s):
        /// *PRE?
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Returns the content of the parallel poll enable register in decimal form.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ParallelPollRegisterQuery(out int Register_Value)
        {
            int pInvokeResult = PInvoke.ParallelPollRegisterQuery(this._handle, out Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// POWER ON STATUS CLEAR determines whether the content of the ENABle registers are retained or reset at power on.
        /// 
        /// The query *PSC? retrieves the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        /// 
        /// Remote-control command(s):
        /// *PSC 0 | 1
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Determines whether the content of the ENABle registers are retained or reset at power on.
        /// 
        /// Valid Values: 0 | 1
        /// 
        /// Default Value: 0
        /// 
        /// Notes:
        /// 
        /// 0: The content of the status registers is retained at power on. If the status registers ESE and SRE are configured accordingly, this may cause a service request to be triggered at power on.
        /// 
        /// 1: The content of the status registers is reset at power on.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int PowerOnStatusClear(int Register_Value)
        {
            int pInvokeResult = PInvoke.PowerOnStatusClear(this._handle, Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// POWER ON STATUS CLEAR QUERY retrieves the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        /// 
        /// Remote-control command(s):
        /// *PSC?
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Returns the contents of the Power-on-Status-Clear flag. The answer is either 0 or 1.
        /// 
        /// Values:
        /// 
        /// 0: The content of the status registers is retained at power on. If the status registers ESE and SRE are configured accordingly, this may cause a service request to be triggered at power on.
        /// 
        /// 1: The content of the status registers is reset at power on.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int PowerOnStatusClearQuery(out int Register_Value)
        {
            int pInvokeResult = PInvoke.PowerOnStatusClearQuery(this._handle, out Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// RECALL calls up the instrument status which was stored under the specified number using the *SAV command or using the MMEMory:STORe:STATe command. "0" corresponds to the power-on state, unless a new instrument setting was stored under this number in the meantime using the MMEMory:STORe:STATe command. This function can also be used to call up the 3 intermediate instrument states which are stored with *SAV.
        /// 
        /// Remote-control command(s):
        /// *RCL
        /// 
        /// </summary>
        /// <param name="Instrument_Status">
        /// Number under which is stored instrument setting.
        /// 
        /// Valid Range: 0 to 10
        /// 
        /// Default Value: 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int Recall(int Instrument_Status)
        {
            int pInvokeResult = PInvoke.Recall(this._handle, Instrument_Status);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// SAVE stores the current device state under the specified number (see also *RCL). This function is used to store the 3 intermediate instrument states and to store the current instrument state internally when the instrument is switched off. This state is then restored at power on.
        /// 
        /// Remote-control command(s):
        /// *SAV
        /// 
        /// </summary>
        /// <param name="Instrument_Status">
        /// Number under which will be stored instrument setting.
        /// 
        /// Valid Range: 0 to 10
        /// 
        /// Default Value: 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int Save(int Instrument_Status)
        {
            int pInvokeResult = PInvoke.Save(this._handle, Instrument_Status);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// SERVICE REQUEST ENABLE sets the service request enable register to the specified value. Bit 6 (MSS enable bit) remains 0. This function determines the conditions under which a service request is triggered. The *SRE? query command reads out the content of the service request enable register in decimal form. Bit 6 is always 0.
        /// 
        /// Remote-control command(s):
        /// *SRE
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Ssets the service request enable register to the specified value.
        /// 
        /// Valid Range: 0 to 255
        /// 
        /// Default Value: 0
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ServiceRequestEnable(int Register_Value)
        {
            int pInvokeResult = PInvoke.ServiceRequestEnable(this._handle, Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// SERVICE REQUEST ENABLE reads out the content of the service request enable register in decimal form. Bit 6 is always 0.
        /// 
        /// Remote-control command(s):
        /// *SRE?
        /// 
        /// </summary>
        /// <param name="Register_Value">
        /// Returns the content of the service request enable register in decimal form.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int ServiceRequestEnableQuery(out int Register_Value)
        {
            int pInvokeResult = PInvoke.ServiceRequestEnableQuery(this._handle, out Register_Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// READ STATUS BYTE QUERY reads out the content of the status byte in decimal form.
        /// 
        /// Remote-control command(s):
        /// *STB?
        /// 
        /// </summary>
        /// <param name="Status_Byte">
        /// Returns the content of the status byte in decimal form.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int StatusByteQuery(out int Status_Byte)
        {
            int pInvokeResult = PInvoke.StatusByteQuery(this._handle, out Status_Byte);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// TRIGGER triggers all actions which are waiting for a trigger event. Specific trigger events can be triggered by means of the "TRIGger" command system (sweep and lists) or the SOURce subsystems (baseband).
        /// 
        /// Remote-control command(s):
        /// *TRG
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int Trigger()
        {
            int pInvokeResult = PInvoke.Trigger(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function triggers all actions waiting for a trigger event in the currently active window and waits for operation completed (OPC) before returning the status code.
        /// 
        /// </summary>
        /// <param name="Timeout">
        /// Sets the timeout for the triggering routine to be finished. If the length of time required for triggering exceeds the timeout value, then the function will return with a timeout error.
        /// 
        /// Valid Range: 0 ms to 600000 ms
        /// 
        /// Default Value: 15000 ms
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TriggerWaitOPC(int Timeout)
        {
            int pInvokeResult = PInvoke.TriggerWaitOPC(this._handle, Timeout);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the operating mode of the trigger connector.
        /// 
        /// Use mode  RSSGS_TRG_CON_OP_MODE_MEASLATENCY to activate the trigger pulse for time measurments.
        /// 
        /// Remote-control command(s):
        /// :CONNector:TRIGger:OMODe &lt;mode&gt;
        /// 
        /// </summary>
        /// <param name="Mode">
        /// This control sets the operating mode of the trigger connector.
        /// 
        /// 
        /// Valid Values:
        /// 
        /// RSSGS_TRG_CON_OP_MODE_IN             (0) - In       
        /// RSSGS_TRG_CON_OP_MODE_LO             (1) - Low    
        /// RSSGS_TRG_CON_OP_MODE_MEASLATENCY    (2) - Measurement Latency
        /// RSSGS_TRG_CON_OP_MODE_MEASMSGARRIVED (3) - Measurement Message Arrived
        /// RSSGS_TRG_CON_OP_MODE_HI             (4) - High
        /// RSSGS_TRG_CON_OP_MODE_FBFAULT        (5) - FB Fault
        /// RSSGS_TRG_CON_OP_MODE_SIGNALVALID    (6) - Signal Valid
        /// RSSGS_TRG_CON_OP_MODE_EXTOUT1        (7) - External Output 1
        /// RSSGS_TRG_CON_OP_MODE_EXTOUT2        (8) - External Output 2
        /// RSSGS_TRG_CON_OP_MODE_BLANK          (9) - Blank
        /// 
        /// Default Value: RSSGS_TRG_CON_OP_MODE_IN (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetTrigConnnectorOpMode(int Mode)
        {
            int pInvokeResult = PInvoke.SetTrigConnnectorOpMode(this._handle, Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function gets the operating mode of the trigger connector.
        /// 
        /// 
        /// Remote-control command(s):
        /// :CONNector:TRIGger:OMODe?
        /// 
        /// </summary>
        /// <param name="Mode">
        /// Displays the operating mode of the trigger connector.
        /// 
        /// Valid Values:
        /// RSSGS_TRG_CON_OP_MODE_IN             (0) - In       
        /// RSSGS_TRG_CON_OP_MODE_LO             (1) - Low    
        /// RSSGS_TRG_CON_OP_MODE_MEASLATENCY    (2) - Measurement Latency
        /// RSSGS_TRG_CON_OP_MODE_MEASMSGARRIVED (3) - Measurement Message Arrived
        /// RSSGS_TRG_CON_OP_MODE_HI             (4) - High
        /// RSSGS_TRG_CON_OP_MODE_FBFAULT        (5) - FB Fault
        /// RSSGS_TRG_CON_OP_MODE_SIGNALVALID    (6) - Signal Valid
        /// RSSGS_TRG_CON_OP_MODE_EXTOUT1        (7) - External Output 1
        /// RSSGS_TRG_CON_OP_MODE_EXTOUT2        (8) - External Output 2
        /// RSSGS_TRG_CON_OP_MODE_BLANK          (9) - Blank
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetTrigConnnectorOpMode(out int Mode)
        {
            int pInvokeResult = PInvoke.GetTrigConnnectorOpMode(this._handle, out Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// SELF TEST QUERY triggers all self tests of the instrument and outputs an error code in decimal form (see Service Manual supplied with the instrument).
        /// 
        /// Remote-control command(s):
        /// *TST?
        /// 
        /// </summary>
        /// <param name="Error_Code">
        /// Returns an error code of the self tests.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SelfTestQuery(out int Error_Code)
        {
            int pInvokeResult = PInvoke.SelfTestQuery(this._handle, out Error_Code);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// WAIT-to-CONTINUE does not allow subsequent commands to be processed until all previous commands have been executed and all signals are in their transient condition.
        /// 
        /// Remote-control command(s):
        /// *WAI
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int WaittoContinue()
        {
            int pInvokeResult = PInvoke.WaittoContinue(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function presets all parameters which are related to the signal path.
        /// 
        /// Remote-control command(s):
        /// SOURce:PRESet
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int PresetSignalPath()
        {
            int pInvokeResult = PInvoke.PresetSignalPath(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the names of the assemblies available in the instrument. 
        /// 
        /// A complete list of all assemblies is returned (the various entries are separated by commas). The length of the list is variable and depends on the instrument equipment configuration. 
        /// 
        /// 
        /// Remote-control command(s):
        /// DIAGnostic:BGINfo:CATalog?
        /// 
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Module Names'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Module_Names">
        /// Returns complete list of all assemblies (the various entries are separated by commas). The length of the list is variable, depends on the instrument equipment configuration and is limited to the size defined by 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int DIAGnosticModuleNames(int Array_Size, System.Text.StringBuilder Module_Names)
        {
            int pInvokeResult = PInvoke.DIAGnosticModuleNames(this._handle, Array_Size, Module_Names);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the test points available in the instrument. A detailed description of the test points can be found in Chapter 3 of the Service Manual (supplied with the instrument).  
        /// 
        /// 
        /// Remote-control command(s):
        /// DIAGnostic:POINt:CATalog?
        /// 
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Test Points'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Test_Points">
        /// Returns the test points available in the instrument (the various entries are separated by commas).
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int DIAGnosticTestPoints(int Array_Size, System.Text.StringBuilder Test_Points)
        {
            int pInvokeResult = PInvoke.DIAGnosticTestPoints(this._handle, Array_Size, Test_Points);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function triggers voltage measurement at the specified test point and returns the measured voltage. A detailed description of the test points can be found in Chapter 3 of the Service Manual (supplied with the instrument). 
        /// 
        /// A list of the available test points can be queried using the DIAG:POIN:CAT? command .   
        /// 
        /// 
        /// Remote-control command(s):
        /// DIAGnostic[:MEASure:]POINt? &lt;test point name&gt;
        /// 
        /// </summary>
        /// <param name="Test_Point_Name">
        /// Test point name.
        /// 
        /// Valid Values: 
        /// not checked
        /// 
        /// Default Value: 
        /// not defined
        /// </param>
        /// <param name="Measured_Voltage">
        /// Returns the voltage measured at the specified test point.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int DIAGnosticTestPointVoltage(string Test_Point_Name, out double Measured_Voltage)
        {
            int pInvokeResult = PInvoke.DIAGnosticTestPointVoltage(this._handle, Test_Point_Name, out Measured_Voltage);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// The respective hardware assembly responds directly to this function; any safety mechanisms are bypassed. 
        /// 
        /// 
        /// Remote-control command(s):
        /// TEST:DIRect? SCOM | RF  
        /// 
        /// 
        /// 
        /// 
        /// </summary>
        /// <param name="Bar">
        /// Selects the device.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Adress">
        /// Selects register address to read from.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Data">
        /// Returns register contents.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int DIAGnosticGetMemoryContent(int Bar, int Adress, out int Data)
        {
            int pInvokeResult = PInvoke.DIAGnosticGetMemoryContent(this._handle, Bar, Adress, out Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the contents of a register on a specific device. For service purposes only.
        /// 
        /// 
        /// Remote-control command(s):
        /// TEST:DIRect
        /// 
        /// 
        /// 
        /// </summary>
        /// <param name="Bar">
        /// Identifies the device.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Adress">
        /// Selects register address.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Data">
        /// The register contents.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int DIAGnosticSetMemoryContent(int Bar, int Adress, int Data)
        {
            int pInvokeResult = PInvoke.DIAGnosticSetMemoryContent(this._handle, Bar, Adress, Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function changes the default drive. This drive is used for all subsequent MMEM commands if no path is specified with them.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:MSIS &lt;drive_name&gt;
        /// </summary>
        /// <param name="Drive">
        /// Drive name parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "D:"
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryChangeDefaultDrive(string Drive)
        {
            int pInvokeResult = PInvoke.MMEMoryChangeDefaultDrive(this._handle, Drive);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the default drive. This drive is used for all subsequent MMEM commands if no path is specified with them.
        /// 
        /// Remote-control command(s):
        /// MMEMory:MSIS?
        /// </summary>
        /// <param name="Array_Size">
        /// Defines size of array in argument Driver.
        /// 
        /// Valid Values:
        /// not checked
        /// 
        /// Default Value: 5
        /// </param>
        /// <param name="Drive">
        /// Default Drive name.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryGetDefaultDrive(int Array_Size, System.Text.StringBuilder Drive)
        {
            int pInvokeResult = PInvoke.MMEMoryGetDefaultDrive(this._handle, Array_Size, Drive);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function changes the default directory. This directory is used for all subsequent MMEM commands if no path is specified with them. It is also possible to change to a higher directory using two dots '..'.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:CDIRectory &lt;directory_name&gt;
        /// </summary>
        /// <param name="Directory_Name">
        /// Directory name parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: ".."
        /// 
        /// Note:
        /// 
        /// It is also possible to change to a higher directory using two dots '..'.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryChangeDirectory(string Directory_Name)
        {
            int pInvokeResult = PInvoke.MMEMoryChangeDirectory(this._handle, Directory_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the current working directory.
        /// 
        /// Remote-control command(s):
        /// MMEMory:CDIR?
        /// </summary>
        /// <param name="Array_Size">
        /// Defines size of array in argument Directory.
        /// 
        /// Valid Values:
        /// not checked
        /// 
        /// Default Value: 1024
        /// </param>
        /// <param name="Directory">
        /// Current working directory.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryGetDirectory(int Array_Size, System.Text.StringBuilder Directory)
        {
            int pInvokeResult = PInvoke.MMEMoryGetDirectory(this._handle, Array_Size, Directory);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function copies the first specified file to the second specified file. Instead of just a file, this function can also be used to copy a complete directory together with all its files. 
        /// 
        /// If &lt;destination&gt; is not specified, &lt;source&gt; is copied to the MMEM:MSIS drive and the MMEM:CDIR directory. Files which already exist with the same name in the destination directory are overwritten without an error message.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:COPY &lt;source&gt;[,&lt;destination&gt;]
        /// 
        /// </summary>
        /// <param name="Source_Path">
        /// Source path of the file or a complete directory together with all its files.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "D:"
        /// 
        /// </param>
        /// <param name="Destination_Path">
        /// Destination path of the file or a directory. If 'Destination Path' is not specified, 'Source Path' is copied to the MMEM:MSIS drive and the MMEM:CDIR directory.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: VI_NULL
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryCopy(string Source_Path, string Destination_Path)
        {
            int pInvokeResult = PInvoke.MMEMoryCopy(this._handle, Source_Path, Destination_Path);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function writes the block data &lt;binary block data&gt; to the file identified by &lt;file_name&gt;. The IEC/IEEE-bus terminator should be set to EOI in order to ensure correct data transfer.
        /// 
        /// This function can be used to transfer stored instrument settings or waveforms directly to the instrument.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:DATA &lt;file_name&gt;[,&lt;binary block data&gt;]
        /// 
        /// </summary>
        /// <param name="File_Name">
        /// File name of the binary block data.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "TEST1.WV"
        /// 
        /// </param>
        /// <param name="Binary_Block_Length">
        /// Defines the number of bytes in the 'Binary Block Data' array.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: none
        /// 
        /// </param>
        /// <param name="Binary_Block_Data">
        /// Binary block data array to be writen to the file defined by 'File Name' parameter with the size limited with 'Binary Block Length' parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: none
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryBlockDataWrite(string File_Name, int Binary_Block_Length, string Binary_Block_Data)
        {
            int pInvokeResult = PInvoke.MMEMoryBlockDataWrite(this._handle, File_Name, Binary_Block_Length, Binary_Block_Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function transfers the specified file from the R&amp;S SGS to the IEC/IEEE bus and then on to the control computer. It is important to ensure that the intermediate memory on the control computer is large enough to take the file. In this case, the setting for the IEC/IEEE-bus terminator is irrelevant.
        /// 
        /// This function can be used to read stored instrument settings or waveforms directly from the instrument.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:DATA? &lt;file_name&gt;
        /// 
        /// </summary>
        /// <param name="File_Name">
        /// File name of the binary block data.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "wave1.wv"
        /// 
        /// </param>
        /// <param name="Binary_Block_Length">
        /// Length of the binary block data array.
        /// 
        /// </param>
        /// <param name="Binary_Block_Data">
        /// Binary block data to be retrieved from the file defined by the 'File Name' parameter. Array size of this parameter must be large enough to store all the retrieved data.
        /// 
        /// Note:
        /// 
        /// To check length of the binary block data, pass VI_NULL as the value of this parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryBlockDataRead(string File_Name, int Binary_Block_Length, System.Text.StringBuilder Binary_Block_Data)
        {
            int pInvokeResult = PInvoke.MMEMoryBlockDataRead(this._handle, File_Name, Binary_Block_Length, Binary_Block_Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function reads out the subdirectories and files of the specified directory. If no directory is specified, the default directory selected with the MMEM:CDIR command is read out. The directories are output in a list (the list entries are separated by commas). 
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:CATalog? &lt;path&gt;
        /// 
        /// </summary>
        /// <param name="Directory_Path">
        /// Directory path parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: VI_NULL
        /// 
        /// Note:
        /// 
        /// If no directory is specified (VI_NULL), the default directory is used.
        /// 
        /// </param>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Catalog List'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Catalog_List">
        /// Reads back catalog list. Size of the list is limited by the 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryCatalog(string Directory_Path, int Array_Size, System.Text.StringBuilder Catalog_List)
        {
            int pInvokeResult = PInvoke.MMEMoryCatalog(this._handle, Directory_Path, Array_Size, Catalog_List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function reads out the subdirectories of the specified directory. If no directory is specified, the default directory selected with the MMEM:CDIR command is read out. The directories are output in a list (the list entries are separated by commas). 
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:DCATalog? &lt;path&gt;
        /// 
        /// </summary>
        /// <param name="Directory_Path">
        /// Directory path parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: VI_NULL
        /// 
        /// Note:
        /// 
        /// If no directory is specified (VI_NULL), the default directory is used.
        /// 
        /// </param>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Catalog List'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Catalog_List">
        /// Reads back catalog list. Size of the list is limited by the 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryDirectoryCatalog(string Directory_Path, int Array_Size, System.Text.StringBuilder Catalog_List)
        {
            int pInvokeResult = PInvoke.MMEMoryDirectoryCatalog(this._handle, Directory_Path, Array_Size, Catalog_List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function deletes the specified file.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:DELete &lt;file_name&gt;
        /// 
        /// </summary>
        /// <param name="File_Name">
        /// File name parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: ""
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryDelete(string File_Name)
        {
            int pInvokeResult = PInvoke.MMEMoryDelete(this._handle, File_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function creates a new subdirectory in the specified directory. If no directory is specified, a subdirectory is created in the default directory. This function can also be used to create a directory tree.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:MDIRectory &lt;directory_name&gt;
        /// 
        /// </summary>
        /// <param name="Directory_Name">
        /// Directory name parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "New_Folder"
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryMakeDirectory(string Directory_Name)
        {
            int pInvokeResult = PInvoke.MMEMoryMakeDirectory(this._handle, Directory_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function renames an existing file ('File Source') if no path is specified for 'File Destination'. Otherwise the file is moved to the specified path and stored under the original file name or, if specified, a new file name.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:MOVE &lt;file_source&gt;,&lt;file_destination&gt;
        /// 
        /// </summary>
        /// <param name="File_Source">
        /// Define file source.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: ""
        /// 
        /// </param>
        /// <param name="File_Destination">
        /// Define file destination.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: ""
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryMove(string File_Source, string File_Destination)
        {
            int pInvokeResult = PInvoke.MMEMoryMove(this._handle, File_Source, File_Destination);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function deletes the specified subdirectory in the specified directory. If no directory is specified, the subdirectory with the specified name is deleted in the default directory.
        /// 
        /// 
        /// Remote-control command(s):
        /// MMEMory:RDIRectory &lt;directory_name&gt;
        /// 
        /// </summary>
        /// <param name="Directory_Name">
        /// Directory name parameter.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: ""
        /// 
        /// Note:
        /// 
        /// If no directory is specified, the subdirectory with the specified name is deleted in the default directory.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int MMEMoryRemoveDirectory(string Directory_Name)
        {
            int pInvokeResult = PInvoke.MMEMoryRemoveDirectory(this._handle, Directory_Name);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// The respective hardware assembly responds directly to this function; any safety mechanisms are bypassed. 
        /// 
        /// 
        /// Remote-control command(s):
        /// TEST:DIRect? SCOM | RF 
        /// 
        /// </summary>
        /// <param name="Instrument_Session">
        /// This control accepts the Instrument Handle returned by the Initialize function to select the desired instrument driver session.
        /// 
        /// Default Value:  None
        /// </param>
        /// <param name="Component">
        /// Selects the hardware component.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Address">
        /// Selects the address to read from.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Data">
        /// Response of the respective hardware assembly.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TESTDirect(int Component, int Address, out int Data)
        {
            int pInvokeResult = PInvoke.TESTDirect(this._handle, Component, Address, out Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function perform a test of the internal voltages. Returns 0 on success.
        /// 
        /// Remote-control command(s):
        /// TEST:VOLTage?
        /// </summary>
        /// <param name="Result">
        /// Returns result of the test. The response "0" indicates error-free testing, and the response "1" means that an error occurred during test.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TESTVoltage(out int Result)
        {
            int pInvokeResult = PInvoke.TESTVoltage(this._handle, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function gets the result or current state of a selftest. Returns 0 on success.
        /// 
        /// Remote-control command(s):
        /// TEST:ALL:RESult?
        /// </summary>
        /// <param name="Result">
        /// Returns result of the test. The response "0" indicates error-free testing, and the response "1" means that an error occurred during test.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TESTSelftestResult(out int Result)
        {
            int pInvokeResult = PInvoke.TESTSelftestResult(this._handle, out Result);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function perform selftest.
        /// 
        /// Remote-control command(s):
        /// TEST:ALL:STARt
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TESTSelftestStart()
        {
            int pInvokeResult = PInvoke.TESTSelftestStart(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function allows us to measure PCIe execution times using an arbitrary remote control channel.
        /// 
        /// Remote-control command(s):
        /// TEST:SPEEd &lt;frequency&gt;,&lt;level&gt;
        /// </summary>
        /// <param name="Frequency">
        /// Sets the frequency.
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0.0
        /// </param>
        /// <param name="Level">
        /// Sets the level.
        /// 
        /// 
        /// Valid Values:
        /// Not checked.
        /// 
        /// Default Value: 0.0
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int TestSpeed(double Frequency, double Level)
        {
            int pInvokeResult = PInvoke.TestSpeed(this._handle, Frequency, Level);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the value of selected status register.
        /// 
        /// Remote-control command(s):
        /// STATus:OPERation:PTRansition
        /// STATus:OPERation:NTRansition
        /// STATus:OPERation:ENABle
        /// STATus:QUEStionable:PTRansition
        /// STATus:QUEStionable:NTRansition
        /// STATus:QUEStionable:ENABle
        /// </summary>
        /// <param name="Register_Group">
        /// Selects the status register group.
        /// 
        /// Valid Values:
        /// RSSGS_REGISTER_OPERATION    (0) - Operation
        /// RSSGS_REGISTER_QUESTIONABLE (1) - Questionable
        /// 
        /// Default Value: RSSGS_REGISTER_OPERATION (0)
        /// 
        /// </param>
        /// <param name="Register_Type">
        /// Selects the type of status register.
        /// 
        /// Valid Values:
        /// RSSGS_REGISTER_ENABLE (2) - Enable
        /// RSSGS_REGISTER_NTR    (3) - Negative Transition
        /// RSSGS_REGISTER_PTR    (4) - Positive Transition
        /// 
        /// Default Value: RSSGS_REGISTER_ENABLE (2)
        /// 
        /// </param>
        /// <param name="Value">
        /// Sets the value to be set to selected register.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: 32767
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetRegister(int Register_Group, int Register_Type, int Value)
        {
            int pInvokeResult = PInvoke.SetRegister(this._handle, Register_Group, Register_Type, Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the value of selected status register.
        /// 
        /// Remote-control command(s):
        /// STATus:OPERation:EVENt?
        /// STATus:OPERation:CONDition?
        /// STATus:OPERation:PTRansition?
        /// STATus:OPERation:NTRansition?
        /// STATus:QUEStionable:EVENt?
        /// STATus:QUEStionable:CONDition?
        /// STATus:QUEStionable:PTRansition?
        /// STATus:QUEStionable:NTRansition?
        /// </summary>
        /// <param name="Register_Group">
        /// Selects the status register group.
        /// 
        /// Valid Values:
        /// RSSGS_REGISTER_OPERATION    (0) - Operation
        /// RSSGS_REGISTER_QUESTIONABLE (1) - Questionable
        /// 
        /// Default Value: RSSGS_REGISTER_OPERATION (0)
        /// 
        /// </param>
        /// <param name="Register_Type">
        /// Selects the type of status register.
        /// 
        /// Valid Values:
        /// RSSGS_REGISTER_COND   (0) - Condition
        /// RSSGS_REGISTER_EVENT  (1) - Event
        /// RSSGS_REGISTER_ENABLE (2) - Enable
        /// RSSGS_REGISTER_NTR    (3) - Negative Transition
        /// RSSGS_REGISTER_PTR    (4) - Positive Transition
        /// 
        /// Default Value: RSSGS_REGISTER_EVENT (1)
        /// </param>
        /// <param name="Value">
        /// Returns the value of selected register.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetRegister(int Register_Group, int Register_Type, out int Value)
        {
            int pInvokeResult = PInvoke.GetRegister(this._handle, Register_Group, Register_Type, out Value);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function resets the status registers. All PTRansition parts are set to FFFFh (32767), i.e. all transitions from 0 to 1 are detected. All NTRansition parts are set to 0, i.e. a transition from 1 to 0 in a CONDition bit is not detected. The ENABle parts of STATus:OPERation and STATus:QUEStionable are set to 0, i.e. all events in these registers are not passed on.
        /// 
        /// 
        /// Remote-control command(s):
        /// STATus:PRESet
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int STATusPRESet()
        {
            int pInvokeResult = PInvoke.STATusPRESet(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries all entries in the error queue and then deletes them. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 ("No error") is returned. 
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:ERRor:ALL?
        /// 
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Error Queue'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Error_Queue">
        /// Returns all entries in the error queue. Buffer length is limited by the 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemErrorQueueAll(int Array_Size, System.Text.StringBuilder Error_Queue)
        {
            int pInvokeResult = PInvoke.SYSTemErrorQueueAll(this._handle, Array_Size, Error_Queue);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries all entries in the error queue and then deletes them. Only the error numbers are returned and not the entire error text. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 ("No error") is returned. 
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:ERRor:CODE:ALL?
        /// 
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Error Queue Code'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Error_Queue_Code">
        /// Returns all entries in the error queue. Only the error numbers are returned and not the entire error text. Buffer length is limited by the 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemErrorQueueCodeAll(int Array_Size, System.Text.StringBuilder Error_Queue_Code)
        {
            int pInvokeResult = PInvoke.SYSTemErrorQueueCodeAll(this._handle, Array_Size, Error_Queue_Code);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the oldest entry in the error queue and then deletes it. Only the error number is returned and not the entire error text. Positive error numbers denote instrument-specific errors, and negative error numbers denote error messages defined by SCPI (see Chapter 9). If the error queue is empty, 0 is returned. 
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:ERRor:CODE[:NEXT]?
        /// 
        /// </summary>
        /// <param name="Error_Queue_Code_Next">
        /// Returns the oldest entry in the error queue. Only the error number is returned and not the entire error text.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemErrorQueueCodeNext(out int Error_Queue_Code_Next)
        {
            int pInvokeResult = PInvoke.SYSTemErrorQueueCodeNext(this._handle, out Error_Queue_Code_Next);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the number of entries in the error queue. If the error queue is empty, '0' is returned.
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:ERRor:COUNt?
        /// 
        /// </summary>
        /// <param name="Error_Queue_Count">
        /// Returns the number of entries in the error queue.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemErrorQueueCount(out int Error_Queue_Count)
        {
            int pInvokeResult = PInvoke.SYSTemErrorQueueCount(this._handle, out Error_Queue_Count);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns a list of all errors existing at the time when the query is started. This list corresponds to the display on the info page under manual control.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SERRor?
        /// 
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Error Queue'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="Error_Queue">
        /// Returns all entries in the error queue. Buffer length is limited by the 'Array Size' parameter.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemStaticErrorQueue(int Array_Size, System.Text.StringBuilder Error_Queue)
        {
            int pInvokeResult = PInvoke.SYSTemStaticErrorQueue(this._handle, Array_Size, Error_Queue);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the USB resource.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:USB:RESource?
        /// </summary>
        /// <param name="Array_Size">
        /// Array size of the parameter labeled 'Error Queue'.
        /// 
        /// Valid Range: &gt; 0
        /// 
        /// Default Value: 256
        /// 
        /// </param>
        /// <param name="USB_Resource">
        /// This control display USB resource.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemUSBResource(uint Array_Size, System.Text.StringBuilder USB_Resource)
        {
            int pInvokeResult = PInvoke.SYSTemUSBResource(this._handle, Array_Size, USB_Resource);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function clears gui error history.
        /// 
        /// Remote-control command(s):
        /// SYSTem:HCLear
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemClearErrorHistory()
        {
            int pInvokeResult = PInvoke.SYSTemClearErrorHistory(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function restore the device state to the factory settings.
        /// 
        /// Remote-control command(s):
        /// SYSTem:FPReset
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemRestoreFactorySettings()
        {
            int pInvokeResult = PInvoke.SYSTemRestoreFactorySettings(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function shutdown the device.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SHUTdown
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SYSTemShutdown()
        {
            int pInvokeResult = PInvoke.SYSTemShutdown(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function activates and deactivates the specified protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only). These levels are identified by the suffix under PROTect.
        /// 
        /// The respective functions are disabled when the protection level is activated. No password is required for activation. A password must be entered to deactivate the protection level.  The password for the first level is 123456. This protection level can be used to lock-out internal adjustments.
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:PROTect&lt;n&gt;[:STATe] ON | OFF, password
        /// 
        /// </summary>
        /// <param name="Protection_Level">
        /// Specify protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only).
        /// 
        /// Valid Range: 1 to 5
        /// 
        /// Default Value: 1
        /// 
        /// </param>
        /// <param name="Protection">
        /// Activates and deactivates the specified protection level.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// 
        /// Default Value: VI_FALSE (0)
        /// 
        /// </param>
        /// <param name="Password">
        /// The password for the specified protection level.
        /// 
        /// Valid Range: not checked
        /// 
        /// Default Value: "123456"
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetSYSTemProtect(int Protection_Level, bool Protection, string Password)
        {
            int pInvokeResult = PInvoke.SetSYSTemProtect(this._handle, Protection_Level, System.Convert.ToUInt16(Protection), Password);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries state of the specified protection level. 
        /// 
        /// Remote-control command(s):
        /// SYSTem:PROTect&lt;n&gt;[:STATe]?
        /// 
        /// </summary>
        /// <param name="Protection_Level">
        /// Specify protection level. There are several protection levels which disable specific service functions (authorized personnel of R&amp;S Service Deparments only).
        /// 
        /// Valid Range: 1 to 5
        /// 
        /// Default Value: 1
        /// 
        /// </param>
        /// <param name="Protection">
        /// Returns state of the specified protection level.
        /// 
        /// Valid Values:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemProtect(int Protection_Level, out bool Protection)
        {
            ushort ProtectionAsUShort;
            int pInvokeResult = PInvoke.GetSYSTemProtect(this._handle, Protection_Level, out ProtectionAsUShort);
            Protection = System.Convert.ToBoolean(ProtectionAsUShort);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the SCPI version with which the instrument complies.
        /// 
        /// 
        /// Remote-control command(s):
        /// SYSTem:VERSion?
        /// 
        /// </summary>
        /// <param name="SCPI_Version">
        /// Returns the SCPI version with which the instrument complies.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 32 elements ViChar[32].
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemVersion(System.Text.StringBuilder SCPI_Version)
        {
            int pInvokeResult = PInvoke.GetSYSTemVersion(this._handle, SCPI_Version);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns if the startup of the instrument is completed.
        /// 
        /// Remote-control command(s):
        /// SYSTem:STARtup:COMPlete?
        /// </summary>
        /// <param name="Startup_Complete">
        /// This control displays the startup of the instrument is completed.
        /// 
        /// Valid Values:
        /// RSSGS_SYSTEM_INCOMPLETE (0) - Startup Incomplete
        /// RSSGS_SYSTEM_COMPLETE   (1) - Startup Complete
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemStartupStatus(out int Startup_Complete)
        {
            int pInvokeResult = PInvoke.GetSYSTemStartupStatus(this._handle, out Startup_Complete);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the Terminator mode for the IEC bus.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:GPIB:LTERminator EOI | STANdard
        /// </summary>
        /// <param name="Mode">
        /// This control sets the Terminator mode for the IEC bus.
        /// 
        /// Valid Values:
        /// RSSGS_TERMINATOR_MODE_EOI  (0) - EOI
        /// RSSGS_TERMINATOR_MODE_STAN (1) - Standard
        /// 
        /// Default Value:
        /// RSSGS_TERMINATOR_MODE_EOI (0)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetSYSTemTerminatorMode(int Mode)
        {
            int pInvokeResult = PInvoke.SetSYSTemTerminatorMode(this._handle, Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the Terminator mode for the IEC bus.
        /// 
        /// Remote-control command(s):
        /// SYSTem:COMMunicate:GPIB:LTERminator?
        /// 
        /// </summary>
        /// <param name="Mode">
        /// Displays the Terminator mode for the IEC bus.
        /// 
        /// Valid Values:
        /// RSSGS_TERMINATOR_MODE_EOI  (0) - EOI
        /// RSSGS_TERMINATOR_MODE_STAN (1) - Standard
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemTerminatorMode(out int Mode)
        {
            int pInvokeResult = PInvoke.GetSYSTemTerminatorMode(this._handle, out Mode);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the system data sheet id catalog.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SPECification:IDENtification:CATalog?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Sheet_Catalog">
        /// Displays the system data sheet id catalog.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemDataSheetCatalog(int Array_Size, System.Text.StringBuilder Sheet_Catalog)
        {
            int pInvokeResult = PInvoke.GetSYSTemDataSheetCatalog(this._handle, Array_Size, Sheet_Catalog);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the data sheet data.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SPECification?
        /// </summary>
        /// <param name="ID">
        /// This control sets the ID.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// ""
        /// </param>
        /// <param name="Sheet_Data">
        /// Displays the selected sheet data.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemDataSheetData(string ID, out double Sheet_Data)
        {
            int pInvokeResult = PInvoke.GetSYSTemDataSheetData(this._handle, ID, out Sheet_Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the data sheet data.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SPECification:PARameter?
        /// </summary>
        /// <param name="ID">
        /// This control sets the ID.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// ""
        /// </param>
        /// <param name="Parameter">
        /// This control sets the parameter.
        /// 
        /// Valid Values:
        /// Not Checked
        /// 
        /// Default Value:
        /// 0.0
        /// </param>
        /// <param name="Sheet_Data">
        /// Displays the selected sheet data.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemDataSheetParameter(string ID, double Parameter, out double Sheet_Data)
        {
            int pInvokeResult = PInvoke.GetSYSTemDataSheetParameter(this._handle, ID, Parameter, out Sheet_Data);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the system data sheet version.
        /// 
        /// Remote-control command(s):
        /// SYSTem:SPECification:VERSion?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="Version">
        /// Displays the system data sheet version.
        /// 
        /// Valid Values:
        /// Not Checked
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemDataSheetVersion(int Array_Size, System.Text.StringBuilder Version)
        {
            int pInvokeResult = PInvoke.GetSYSTemDataSheetVersion(this._handle, Array_Size, Version);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns a list of hardware assembly names.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:NAME?
        /// </summary>
        /// <param name="Assembly_Index">
        /// This control sets the assembly index.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        /// RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        /// 
        /// Default Value:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of hardware assembly names.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemHwAssemblyNames(int Assembly_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemHwAssemblyNames(this._handle, Assembly_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system hardware part numbers. 
        /// 
        /// Remote-control command(s):
        /// :SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:PNUMber?
        /// 
        /// </summary>
        /// <param name="Assembly_Index">
        /// This control sets the assembly index.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        /// RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        /// 
        /// Default Value:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of system hardware part numbers. 
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemHwPartNumbers(int Assembly_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemHwPartNumbers(this._handle, Assembly_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system hardware revisions.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:REVision?
        /// </summary>
        /// <param name="Assembly_Index">
        /// This control sets the assembly index.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        /// RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        /// 
        /// Default Value:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the the list of system hardware revisions.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemHwRevisions(int Assembly_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemHwRevisions(this._handle, Assembly_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of hardware module serial numbers.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:HARDware:ASSembly&lt;AssemblyIndex&gt;:SNUMber?
        /// 
        /// </summary>
        /// <param name="Assembly_Index">
        /// This control sets the assembly index.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0) - Common
        /// RSSGS_VAL_ASSEMBLY_INDEX_RF      (1) - RF
        /// 
        /// Default Value:
        /// RSSGS_VAL_ASSEMBLY_INDEX_COMMON  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of hardware module serial numbers.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemHwSerialNumbers(int Assembly_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemHwSerialNumbers(this._handle, Assembly_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system firmware package names.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:FIRMware:PACKage?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of system firmware package names.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwFirmwarePackages(int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwFirmwarePackages(this._handle, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system firmware versions.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:FIRMware:VERSion?
        /// </summary>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of system firmware versions.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwFirmwareVersions(int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwFirmwareVersions(this._handle, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of option descriptions.
        /// 
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:DESignation?
        /// 
        /// 
        /// </summary>
        /// <param name="Option_Index">
        /// This control selects the option group.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        /// RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        /// 
        /// Default Value:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of option descriptions.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwOptionDesignations(int Option_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwOptionDesignations(this._handle, Option_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system firmware option names.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:NAME?
        /// 
        /// </summary>
        /// <param name="Option_Index">
        /// This control selects the option group.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        /// RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        /// 
        /// Default Value:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of system firmware option names.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwOptionNames(int Option_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwOptionNames(this._handle, Option_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system firmware option expiration entries.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:EXP?
        /// 
        /// </summary>
        /// <param name="Option_Index">
        /// This control selects the option group.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        /// RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        /// 
        /// Default Value:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// Displays the list of system firmware option expiration entries.
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwOptionExpirations(int Option_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwOptionExpirations(this._handle, Option_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function queries the list of system firmware option license count entries.
        /// 
        /// Remote-control command(s):
        /// :SYSTem:SOFTware:OPTion&lt;OptionIndex&gt;:LIC?
        /// 
        /// </summary>
        /// <param name="Option_Index">
        /// This control selects the option group.
        /// 
        /// Valid Values:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0) - Hardware
        /// RSSGS_VAL_OPTION_INDEX_SOFTWARE  (1) - Software
        /// 
        /// Default Value:
        /// RSSGS_VAL_OPTION_INDEX_HARDWARE  (0)
        /// </param>
        /// <param name="Array_Size">
        /// This control sets the array size.
        /// 
        /// Valid Values:
        /// &gt; 0
        /// 
        /// Default Value:
        /// 64
        /// </param>
        /// <param name="List">
        /// list of system firmware option license count entries
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetSYSTemSwOptionLicenses(int Option_Index, int Array_Size, System.Text.StringBuilder List)
        {
            int pInvokeResult = PInvoke.GetSYSTemSwOptionLicenses(this._handle, Option_Index, Array_Size, List);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the default unit for angles. It is valid for all commands which determine angle values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Remote-control command(s):
        /// UNIT:ANGle DEG | RAD
        /// </summary>
        /// <param name="Angle_Units">
        /// Sets the default unit for angles. It is valid for all commands which determine angle values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Valid Values:
        /// RSSGS_UNIT_ANGLE_DEG (0) - Degrees
        /// RSSGS_UNIT_ANGLE_RAD (1) - Radius
        /// 
        /// Default Value: RSSGS_UNIT_ANGLE_RAD (1)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetAngleUnits(int Angle_Units)
        {
            int pInvokeResult = PInvoke.SetAngleUnits(this._handle, Angle_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the unit for angles. 
        /// 
        /// Remote-control command(s):
        /// UNIT:ANGle?
        /// </summary>
        /// <param name="Angle_Units">
        /// Gets the unit for angles. 
        /// 
        /// Valid Values:
        /// RSSGS_UNIT_ANGLE_DEG (0) - Degrees
        /// RSSGS_UNIT_ANGLE_RAD (1) - Radius
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetAngleUnits(out int Angle_Units)
        {
            int pInvokeResult = PInvoke.GetAngleUnits(this._handle, out Angle_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the default unit for power. It is valid for all commands which determine power values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Remote-control command(s):
        /// UNIT:POWer V | DBM
        /// </summary>
        /// <param name="Power_Units">
        /// Sets the default unit for power. It is valid for all commands which determine power values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Valid Values:
        /// RSSGS_UNIT_POWER_V   (0) - V
        /// RSSGS_UNIT_POWER_DBM (1) - dBm
        /// 
        /// Default Value: RSSGS_UNIT_POWER_DBM (1)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetPowerUnits(int Power_Units)
        {
            int pInvokeResult = PInvoke.SetPowerUnits(this._handle, Power_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the unit for power.
        /// 
        /// Remote-control command(s):
        /// UNIT:POWer?
        /// </summary>
        /// <param name="Power_Units">
        /// Gets the unit for power.
        /// 
        /// Valid Values:
        /// RSSGS_UNIT_POWER_V   (0) - V
        /// RSSGS_UNIT_POWER_DBM (1) - dBm
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetPowerUnits(out int Power_Units)
        {
            int pInvokeResult = PInvoke.GetPowerUnits(this._handle, out Power_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Remote-control command(s):
        /// UNIT:VELocity  
        /// </summary>
        /// <param name="Velocity_Units">
        /// Sets the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Valid Values:
        /// RSSGS_UNIT_VELOCITY_MPS (0) - MPS
        /// RSSGS_UNIT_VELOCITY_KMH (1) - KMH
        /// RSSGS_UNIT_VELOCITY_MPH (2) - MPH
        /// 
        /// Default Value: RSSGS_UNIT_VELOCITY_MPS (0)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssmf_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetVelocityUnits(int Velocity_Units)
        {
            int pInvokeResult = PInvoke.SetVelocityUnits(this._handle, Velocity_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the default unit for velocity. It is valid for all commands which determine velocity values. It does not influence the manual control parameter unit and the display.
        /// 
        /// Remote-control command(s):
        /// UNIT:VELocity?
        /// </summary>
        /// <param name="Velocity_Units">
        /// Displays the default unit for velocity. 
        /// 
        /// Valid Values:
        /// RSSMB_UNIT_VELOCITY_MPS (0) - MPS
        /// RSSMB_UNIT_VELOCITY_KMH (1) - KMH
        /// RSSMB_UNIT_VELOCITY_MPH (2) - MPH
        /// 
        /// 
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssmf_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetVelocityUnits(out int Velocity_Units)
        {
            int pInvokeResult = PInvoke.GetVelocityUnits(this._handle, out Velocity_Units);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function sets the data format for IEC bus.
        /// 
        /// Remote-control command(s):
        /// FORMat[:DATA] ASCii | PACKed
        /// </summary>
        /// <param name="Format">
        /// Sets the data format for IEC bus.
        /// 
        /// Valid Values:
        /// RSSGS_FORMAT_DATA_ASCII (0) - ASCII
        /// RSSGS_FORMAT_DATA_PACK  (1) - Packet
        /// 
        /// Default Value:
        /// RSSGS_FORMAT_DATA_ASCII (0)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int SetFormatData(int Format)
        {
            int pInvokeResult = PInvoke.SetFormatData(this._handle, Format);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the data format for IEC bus.
        /// 
        /// Remote-control command(s):
        /// FORMat[:DATA]?
        /// </summary>
        /// <param name="Format">
        /// Displays the data format for IEC bus.
        /// 
        /// Valid Values:
        /// RSSGS_FORMAT_DATA_ASCII (0) - ASCII
        /// RSSGS_FORMAT_DATA_PACK  (1) - Packet
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int GetFormatData(out int Format)
        {
            int pInvokeResult = PInvoke.GetFormatData(this._handle, out Format);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function switches state checking of the instrument (reading of the Standard Event Register and checking it for error) status subsystem. Driver functions are using state checking which is by default enabled.
        /// 
        /// Note:
        /// 
        /// (1) In debug mode enable state checking.
        /// 
        /// (2) For better bus throughput and instruments performance disable state checking.
        /// 
        /// (3) When state checking is disabled driver does not check if correct instrument model or option is used with each of the functions. This might cause unexpected behaviour of the instrument.
        /// 
        /// </summary>
        /// <param name="State_Checking">
        /// This control switches instrument state checking On or Off.
        /// 
        /// Valid Range:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On (Default Value)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This driver defines the following status codes:
        ///           
        /// Status    Description
        /// -------------------------------------------------
        /// BFFC0002  Parameter 2 (State Checking) out of range.
        ///           
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int errorCheckState(bool State_Checking)
        {
            int pInvokeResult = PInvoke.errorCheckState(this._handle, System.Convert.ToUInt16(State_Checking));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function switches option checking of the instrument.
        /// </summary>
        /// <param name="State_Checking">
        /// This control switches instrument and option checking On or Off.
        /// 
        /// Valid Range:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On (Default Value)
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This driver defines the following status codes:
        ///           
        /// Status    Description
        /// -------------------------------------------------
        /// BFFC0002  Parameter 2 (State Checking) out of range.
        ///           
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int optionCheckState(bool State_Checking)
        {
            int pInvokeResult = PInvoke.optionCheckState(this._handle, System.Convert.ToUInt16(State_Checking));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function switches range checking of the instrument.
        /// </summary>
        /// <param name="Range_Checking">
        /// This control switches instrument and range checking On or Off.
        /// 
        /// Valid Range:
        /// VI_FALSE (0) - Off
        /// VI_TRUE  (1) - On (Default Value)
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This driver defines the following status codes:
        ///           
        /// Status    Description
        /// -------------------------------------------------
        /// BFFC0002  Parameter 2 (State Checking) out of range.
        ///           
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int setCheckRange(bool Range_Checking)
        {
            int pInvokeResult = PInvoke.setCheckRange(this._handle, System.Convert.ToUInt16(Range_Checking));
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function writes commands and queries to the instrument to modify parameters and query device settings.
        /// </summary>
        /// <param name="Write_Buffer">
        /// The user can use this control to send common commands and queries to the instrument. This control can also be used to write any valid command to the instrument.
        /// 
        /// Default Value:  "*RST"
        /// 
        /// Notes:
        /// 
        /// (1) This function or query to be sent to the instrument may be a literal enclosed in double quotes i.e. "*RST" or may be contained in a variable of type string.
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int writeInstrData(string Write_Buffer)
        {
            int pInvokeResult = PInvoke.writeInstrData(this._handle, Write_Buffer);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function reads data from the instrument's output buffer and returns it to the specified variable in memory.
        /// 
        /// Notes:
        /// 
        /// (1) Because the instrument may return both numeric and text data in response to queries this function returns the data in string format.
        /// 
        /// (2) If valid data is not available at the instrument's output buffer when this function is called the instrument will hang up and the function will not return until it times out.  If the time-out is disabled this function will hang indefinitely and it may be necessary to reboot the computer to break out.
        /// </summary>
        /// <param name="Number_Bytes_To_Read">
        /// The number of bytes specified by this control should be greater than or equal to the number of bytes which are to be read from the instrument. If the actual number of bytes to be read is greater than the number this control specifies then multiple reads will be required to empty the instrument's output buffer.
        /// 
        /// If the instrument's output buffer is not emptied the instrument may return invalid data when future reads are performed.
        /// 
        /// Default Value:  50 (See NOTE 2)
        /// 
        /// Notes:
        /// 
        /// (1) If NO DATA is available at the instrument's output buffer when this function is called the instrument will hang up and the function will not return until it times out.  If the time-out is disabled, this function will hang indefinitely and it may be necessary to reboot the computer.
        /// 
        /// (2) If the number of bytes expected is greater than 50 the value of this control may be increased. If the actual number of bytes read is larger than the declared size of the read buffer a run-time error will be generated.
        /// 
        /// </param>
        /// <param name="Read_Buffer">
        /// The incoming data from the instrument is placed into this variable.
        /// 
        /// Notes:
        /// 
        /// (1) Because the instrument may return both numeric and text data in response to queries this function returns the data in string format.
        /// 
        /// (2) This function does not overwrite any old data left in the string variable from the last time the function was called. String data in LabWindows/CVI is terminated with an ASCII null(0x0) and string manipulation functions will only recognize data before the ASCII null.
        /// 
        /// (3) The declared size of the string variable must be greater than the actual number of bytes read from the instrument if it is not a run-time error will be generated.
        /// 
        /// </param>
        /// <param name="NumBytes_Read">
        /// This variable contains the actual number of bytes read from the instrument. This is the value which is returned by the read function.
        /// 
        /// Notes:
        /// 
        /// (1) If the actual number of bytes read is less than the number of bytes specified in the Number Bytes To Read control then the output buffer has probably been emptied. If the read function fails and the number of bytes read is 0, the most probable cause for the failure is there was no data available at the instrument's output buffer.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int readInstrData(int Number_Bytes_To_Read, System.Text.StringBuilder Read_Buffer, out int NumBytes_Read)
        {
            int pInvokeResult = PInvoke.readInstrData(this._handle, Number_Bytes_To_Read, Read_Buffer, out NumBytes_Read);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// RESET resets the instrument to a defined default state. The function has the same effect as pressing the PRESET key.
        /// 
        /// Remote-control command(s):
        /// *RST
        /// *CLS
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int reset()
        {
            int pInvokeResult = PInvoke.reset(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// clears the device's input and output buffers
        /// 
        /// Remote-control command(s):
        /// 
        /// </summary>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int Clear()
        {
            int pInvokeResult = PInvoke.Clear(this._handle);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function runs the instrument's self test routine and returns the test result(s).
        /// 
        /// </summary>
        /// <param name="Self_Test_Result">
        /// This control contains the value returned from the instrument self test. Zero means success. For any other code, see the device's operator's manual.
        /// 
        /// </param>
        /// <param name="Self_Test_Message">
        /// This control contains the string returned from the self test. See the device's operation manual for an explanation of the string's contents.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 256 elements ViChar[256].
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This driver defines the following status codes:
        ///           
        /// Status    Description
        /// -------------------------------------------------
        /// BFFC0002  Parameter 2 (Self-Test Result) NULL pointer.
        ///           
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int self_test(out short Self_Test_Result, System.Text.StringBuilder Self_Test_Message)
        {
            int pInvokeResult = PInvoke.self_test(this._handle, out Self_Test_Result, Self_Test_Message);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function reads an error code from the instrument's error queue.
        /// 
        /// </summary>
        /// <param name="Error_Code">
        /// This control returns the error code read from the instrument's error queue.
        /// 
        /// </param>
        /// <param name="Error_Message">
        /// This control returns the error message string read from the instrument's error message queue.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 256 elements ViChar[256].
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This driver defines the following status codes:
        ///           
        /// Status    Description
        /// -------------------------------------------------
        /// BFFC0002  Parameter 2 (Error Code) NULL pointer.
        /// BFFC0003  Parameter 3 (Error Message) NULL pointer.
        ///           
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int error_query(out int Error_Code, System.Text.StringBuilder Error_Message)
        {
            int pInvokeResult = PInvoke.error_query(this._handle, out Error_Code, Error_Message);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function returns the revision numbers of the instrument driver and instrument firmware, and tells the user with which  instrument firmware this revision of the driver is compatible.
        /// 
        /// </summary>
        /// <param name="Instrument_Driver_Revision">
        /// This control returns the Instrument Driver Software Revision.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 256 elements ViChar[256].
        /// 
        /// </param>
        /// <param name="Firmware_Revision">
        /// This control returns the Instrument Firmware Revision.
        /// 
        /// Notes:
        /// 
        /// (1) The array must contain at least 256 elements ViChar[256].
        /// 
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int revision_query(System.Text.StringBuilder Instrument_Driver_Revision, System.Text.StringBuilder Firmware_Revision)
        {
            int pInvokeResult = PInvoke.revision_query(this._handle, Instrument_Driver_Revision, Firmware_Revision);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function suspends the program for the selected number of second.
        /// </summary>
        /// <param name="Seconds">
        /// This control sets the number of seconds.
        /// 
        /// Valid Values: not checked
        /// 
        /// Default Value: 0.0 s
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public int delay(double Seconds)
        {
            int pInvokeResult = PInvoke.delay(this._handle, Seconds);
            PInvoke.TestForError(this._handle, pInvokeResult);
            return pInvokeResult;
        }

        /// <summary>
        /// This function enumerates PCIe devices.
        /// 
        /// Remote-control command(s):
        /// 
        /// </summary>
        /// <param name="Vendor_ID">
        /// Vendor ID.
        /// 
        /// Valid Values:
        /// not checked
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Device_ID">
        /// Device ID.
        /// 
        /// Valid Values:
        /// not checked
        /// 
        /// Default Value: 0
        /// </param>
        /// <param name="Serial_Numbers">
        /// Array of returned serial numbers. Allocated by caller.
        /// </param>
        /// <param name="Array_Size">
        /// Size of 'Serial Numbers' array. On return: number of found devices.
        /// </param>
        /// <returns>
        /// Returns the status code of this operation. The status code  either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rssgs_error_message function.
        ///           
        /// The general meaning of the status code is as follows:
        /// 
        /// Value                  Meaning
        /// -------------------------------
        /// 0                      Success
        /// Positive Values        Warnings
        /// Negative Values        Errors
        /// 
        /// This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        ///           
        /// Numeric Range (in Hex)   Status Code Types    
        /// -------------------------------------------------
        /// 3FFF0000 to 3FFFFFFF     VISA     Warnings
        /// 3FFC0000 to 3FFCFFFF     VXIPnP   Driver Warnings
        ///           
        /// BFFF0000 to BFFFFFFF     VISA     Errors
        /// BFFC0000 to BFFCFFFF     VXIPnP   Driver Errors
        /// 
        /// </returns>
        public static int enumerate_pcie_devices(int Vendor_ID, int Device_ID, int[] Serial_Numbers, out int Array_Size)
        {
            int pInvokeResult = PInvoke.enumerate_pcie_devices(Vendor_ID, Device_ID, Serial_Numbers, out Array_Size);
            PInvoke.TestForError(new System.Runtime.InteropServices.HandleRef(null, System.IntPtr.Zero), pInvokeResult);
            return pInvokeResult;
        }

        public void Dispose()
        {
            this.Dispose(true);
            System.GC.SuppressFinalize(this);
        }

        private void Dispose(bool disposing)
        {
            if ((this._disposed == false))
            {
                PInvoke.close(this._handle);
                this._handle = new System.Runtime.InteropServices.HandleRef(null, System.IntPtr.Zero);
            }
            this._disposed = true;
        }

        private class PInvoke
        {

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_init", CallingConvention = CallingConvention.StdCall)]
            public static extern int init(string Resource_Name, ushort ID_Query, ushort Reset_Device, out System.IntPtr Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequencyAndLevel", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequencyAndLevel(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Frequency, double Level);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_UseFastSettings", CallingConvention = CallingConvention.StdCall)]
            public static extern int UseFastSettings(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort Fast_Enabled, ushort Asynchronous_Enabled);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_FastSync", CallingConvention = CallingConvention.StdCall)]
            public static extern int FastSync(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetRFState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetRFState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetRFState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetRFState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetRFNumberofPaths", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetRFNumberofPaths(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Paths);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetRFAttenuatorMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetRFAttenuatorMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Attenuator_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetRFAttenuatorMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetRFAttenuatorMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Attenuator_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetOperationMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetOperationMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Operation_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetOperationMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetOperationMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Operation_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetBasebandPaths", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetBasebandPaths(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Baseband_Paths);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureFrequencyLocalOscillator", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureFrequencyLocalOscillator(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Source, int Output);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequencyDeltaPhase", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequencyDeltaPhase(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Delta_Phase);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetFrequencyDeltaPhase", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetFrequencyDeltaPhase(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Delta_Phase);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequencyDeltaPhaseAsCurrent", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequencyDeltaPhaseAsCurrent(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequencyLocalOscillatorSource", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequencyLocalOscillatorSource(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Source);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetFrequencyLocalOscillatorSource", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetFrequencyLocalOscillatorSource(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Source);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFrequencyLocalOscillatorOutput", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFrequencyLocalOscillatorOutput(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Output);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetFrequencyLocalOscillatorOutput", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetFrequencyLocalOscillatorOutput(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Output);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureReferenceOscillator", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureReferenceOscillator(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Source, int Reference_Frequency, int External_Reference_Frequency, int Local_Oscillator_Source, int Local_Oscillator_Output);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCSource", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCSource(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Source);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCSource", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCSource(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Source);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCReferenceOutputFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCReferenceOutputFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Reference_Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCReferenceOutputFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCReferenceOutputFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Reference_Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCExternalReferenceFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCExternalReferenceFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, int External_Reference_Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCExternalReferenceFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCExternalReferenceFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int External_Reference_Frequency);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCExternalSyncBandwidth", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCExternalSyncBandwidth(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Synchronization_Bandwidth);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCExternalSyncBandwidth", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCExternalSyncBandwidth(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Synchronization_Bandwidth);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCCalibrationData", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCCalibrationData(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCCalibrationData", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCCalibrationData(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCAdjustmentActive", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCAdjustmentActive(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort Adjustment_Active);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCAdjustmentActive", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCAdjustmentActive(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort Adjustment_Active);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetROSCAdjustmentValue", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetROSCAdjustmentValue(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Adjustment_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetROSCAdjustmentValue", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetROSCAdjustmentValue(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Adjustment_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevel", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevel(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Level);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureLevelSettings", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureLevelSettings(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Mode, int Setting_Characteristic, double Limit);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevelMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevelMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevelMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevelMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevelSettingCharacteristic", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevelSettingCharacteristic(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Setting_Characteristic);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevelSettingCharacteristic", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevelSettingCharacteristic(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Setting_Characteristic);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevel", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevel(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Level);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevelLimit", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevelLimit(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Limit);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevelLimit", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevelLimit(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Limit);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevelPowerOnState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevelPowerOnState(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Power_On_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevelPowerOnState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevelPowerOnState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Power_On_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetLevelALCState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetLevelALCState(System.Runtime.InteropServices.HandleRef Instrument_Handle, int State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetLevelALCState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetLevelALCState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ReadjustLevelALC", CallingConvention = CallingConvention.StdCall)]
            public static extern int ReadjustLevelALC(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetAttenuatorModeAfterOn", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetAttenuatorModeAfterOn(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetAttenuatorModeAfterOn", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetAttenuatorModeAfterOn(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetAttenuatorSwitchOverOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetAttenuatorSwitchOverOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetAttenuatorSwitchOverOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetAttenuatorSwitchOverOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetAttenuatorLowerRange", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetAttenuatorLowerRange(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Attenuator_Lower_Range);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetAttenuatorUpperRange", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetAttenuatorUpperRange(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Attenuator_Upper_Range);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureIQ", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureIQ(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort IQ_Modulator_State, ushort IQ_Wideband);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureIQImpairments", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureIQImpairments(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State, double I_Offset, double Q_Offset, double Gain_Imbalance, double Quadrature_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQModulatorState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQModulatorState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort IQ_Modulator_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQModulatorState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQModulatorState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort IQ_Modulator_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQImpairmentsState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQImpairmentsState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQImpairmentsState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQImpairmentsState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQImpairmentsIOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQImpairmentsIOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, double I_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQImpairmentsIOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQImpairmentsIOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double I_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQImpairmentsQOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQImpairmentsQOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Q_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQImpairmentsQOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQImpairmentsQOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Q_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQImpairmentsGainImbalance", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQImpairmentsGainImbalance(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Gain_Imbalance);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQImpairmentsGainImbalance", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQImpairmentsGainImbalance(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Gain_Imbalance);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQImpairmentsQuadratureOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQImpairmentsQuadratureOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Quadrature_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQImpairmentsQuadratureOffset", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQImpairmentsQuadratureOffset(System.Runtime.InteropServices.HandleRef Instrument_Handle, out double Quadrature_Offset);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetIQWideband", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetIQWideband(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort IQ_Wideband);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetIQWideband", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetIQWideband(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort IQ_Wideband);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureExtension", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureExtension(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State, int Hardware_Channel, string Instrument_Name, int Serial_Number);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetExtensionState", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetExtensionState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetExtensionHardwareChannel", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetExtensionHardwareChannel(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Hardware_Channel);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionHardwareChannel", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionHardwareChannel(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Hardware_Channel);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetExtensionInstrumentName", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetExtensionInstrumentName(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Instrument_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionInstrumentName", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionInstrumentName(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Instrument_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetExtensionSerialNumber", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetExtensionSerialNumber(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Serial_Number);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionSerialNumber", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionSerialNumber(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Serial_Number);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionRemoteState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionRemoteState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Remote_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetExtensionBusyState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetExtensionBusyState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Busy_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_LockInstrument", CallingConvention = CallingConvention.StdCall)]
            public static extern int LockInstrument(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Lock_ID, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_UnlockInstrument", CallingConvention = CallingConvention.StdCall)]
            public static extern int UnlockInstrument(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Lock_ID);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_CALibrationAll", CallingConvention = CallingConvention.StdCall)]
            public static extern int CALibrationAll(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_CALibrationLevel", CallingConvention = CallingConvention.StdCall)]
            public static extern int CALibrationLevel(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_CALibrationSynthesis", CallingConvention = CallingConvention.StdCall)]
            public static extern int CALibrationSynthesis(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_CALibrationIQModulator", CallingConvention = CallingConvention.StdCall)]
            public static extern int CALibrationIQModulator(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_CALibrationIQModulatorForCurrentFrequency", CallingConvention = CallingConvention.StdCall)]
            public static extern int CALibrationIQModulatorForCurrentFrequency(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkSystemSettings", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkSystemSettings(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkMACAddress", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkMACAddress(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder MAC_Address);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ConfigureNetworkIP", CallingConvention = CallingConvention.StdCall)]
            public static extern int ConfigureNetworkIP(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Address_Mode, string IP_Address, string Subnet_Mask, string Default_Gateway);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkResource", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkResource(System.Runtime.InteropServices.HandleRef Instrument_Handle, uint Array_Size, System.Text.StringBuilder Resource);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkConfigurationState", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkConfigurationState(System.Runtime.InteropServices.HandleRef Instrument_Handle, out ushort Configuration);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetNetworkCommonHostname", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetNetworkCommonHostname(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Hostname);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkCommonHostname", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkCommonHostname(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Hostname);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetNetworkIPAddressMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetNetworkIPAddressMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Address_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkIPAddressMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkIPAddressMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Address_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetNetworkIPAddress", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetNetworkIPAddress(System.Runtime.InteropServices.HandleRef Instrument_Handle, string IP_Address);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkIPAddress", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkIPAddress(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder IP_Address);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetNetworkIPSubnetMask", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetNetworkIPSubnetMask(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Subnet_Mask);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkIPSubnetMask", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkIPSubnetMask(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Subnet_Mask);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetNetworkIPDefaultGateway", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetNetworkIPDefaultGateway(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Default_Gateway);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetNetworkIPDefaultGateway", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetNetworkIPDefaultGateway(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Default_Gateway);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_AcceptNetworkIPSettings", CallingConvention = CallingConvention.StdCall)]
            public static extern int AcceptNetworkIPSettings(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetRemoteOperationMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetRemoteOperationMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Operation_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetRemoteOperationMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetRemoteOperationMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Operation_Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ClearStatus", CallingConvention = CallingConvention.StdCall)]
            public static extern int ClearStatus(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_EventStatusEnable", CallingConvention = CallingConvention.StdCall)]
            public static extern int EventStatusEnable(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_EventStatusQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int EventStatusQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_IdentificationQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int IdentificationQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, System.Text.StringBuilder Instrument_Identification);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_IndividualStatusQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int IndividualStatusQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int IST_Flag);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_OperationComplete", CallingConvention = CallingConvention.StdCall)]
            public static extern int OperationComplete(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_OperationCompleteQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int OperationCompleteQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int OPC_State);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_OptionIdentificationQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int OptionIdentificationQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, System.Text.StringBuilder Option_Identification);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ParallelPollRegisterEnable", CallingConvention = CallingConvention.StdCall)]
            public static extern int ParallelPollRegisterEnable(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ParallelPollRegisterQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int ParallelPollRegisterQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_PowerOnStatusClear", CallingConvention = CallingConvention.StdCall)]
            public static extern int PowerOnStatusClear(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_PowerOnStatusClearQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int PowerOnStatusClearQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_Recall", CallingConvention = CallingConvention.StdCall)]
            public static extern int Recall(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Instrument_Status);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_Save", CallingConvention = CallingConvention.StdCall)]
            public static extern int Save(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Instrument_Status);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ServiceRequestEnable", CallingConvention = CallingConvention.StdCall)]
            public static extern int ServiceRequestEnable(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_ServiceRequestEnableQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int ServiceRequestEnableQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Register_Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_StatusByteQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int StatusByteQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Status_Byte);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_Trigger", CallingConvention = CallingConvention.StdCall)]
            public static extern int Trigger(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TriggerWaitOPC", CallingConvention = CallingConvention.StdCall)]
            public static extern int TriggerWaitOPC(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Timeout);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetTrigConnnectorOpMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetTrigConnnectorOpMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetTrigConnnectorOpMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetTrigConnnectorOpMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SelfTestQuery", CallingConvention = CallingConvention.StdCall)]
            public static extern int SelfTestQuery(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Error_Code);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_WaittoContinue", CallingConvention = CallingConvention.StdCall)]
            public static extern int WaittoContinue(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_PresetSignalPath", CallingConvention = CallingConvention.StdCall)]
            public static extern int PresetSignalPath(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_DIAGnosticModuleNames", CallingConvention = CallingConvention.StdCall)]
            public static extern int DIAGnosticModuleNames(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Module_Names);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_DIAGnosticTestPoints", CallingConvention = CallingConvention.StdCall)]
            public static extern int DIAGnosticTestPoints(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Test_Points);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_DIAGnosticTestPointVoltage", CallingConvention = CallingConvention.StdCall)]
            public static extern int DIAGnosticTestPointVoltage(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Test_Point_Name, out double Measured_Voltage);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_DIAGnosticGetMemoryContent", CallingConvention = CallingConvention.StdCall)]
            public static extern int DIAGnosticGetMemoryContent(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Bar, int Adress, out int Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_DIAGnosticSetMemoryContent", CallingConvention = CallingConvention.StdCall)]
            public static extern int DIAGnosticSetMemoryContent(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Bar, int Adress, int Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryChangeDefaultDrive", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryChangeDefaultDrive(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Drive);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryGetDefaultDrive", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryGetDefaultDrive(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Drive);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryChangeDirectory", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryChangeDirectory(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Directory_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryGetDirectory", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryGetDirectory(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Directory);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryCopy", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryCopy(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Source_Path, string Destination_Path);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryBlockDataWrite", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryBlockDataWrite(System.Runtime.InteropServices.HandleRef Instrument_Handle, string File_Name, int Binary_Block_Length, string Binary_Block_Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryBlockDataRead", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryBlockDataRead(System.Runtime.InteropServices.HandleRef Instrument_Handle, string File_Name, int Binary_Block_Length, System.Text.StringBuilder Binary_Block_Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryCatalog", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryCatalog(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Directory_Path, int Array_Size, System.Text.StringBuilder Catalog_List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryDirectoryCatalog", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryDirectoryCatalog(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Directory_Path, int Array_Size, System.Text.StringBuilder Catalog_List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryDelete", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryDelete(System.Runtime.InteropServices.HandleRef Instrument_Handle, string File_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryMakeDirectory", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryMakeDirectory(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Directory_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryMove", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryMove(System.Runtime.InteropServices.HandleRef Instrument_Handle, string File_Source, string File_Destination);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_MMEMoryRemoveDirectory", CallingConvention = CallingConvention.StdCall)]
            public static extern int MMEMoryRemoveDirectory(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Directory_Name);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TESTDirect", CallingConvention = CallingConvention.StdCall)]
            public static extern int TESTDirect(System.Runtime.InteropServices.HandleRef Instrument_Session, int Component, int Address, out int Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TESTVoltage", CallingConvention = CallingConvention.StdCall)]
            public static extern int TESTVoltage(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TESTSelftestResult", CallingConvention = CallingConvention.StdCall)]
            public static extern int TESTSelftestResult(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Result);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TESTSelftestStart", CallingConvention = CallingConvention.StdCall)]
            public static extern int TESTSelftestStart(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_TestSpeed", CallingConvention = CallingConvention.StdCall)]
            public static extern int TestSpeed(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Frequency, double Level);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetRegister", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetRegister(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Group, int Register_Type, int Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetRegister", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetRegister(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Register_Group, int Register_Type, out int Value);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_STATusPRESet", CallingConvention = CallingConvention.StdCall)]
            public static extern int STATusPRESet(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemErrorQueueAll", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemErrorQueueAll(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Error_Queue);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemErrorQueueCodeAll", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemErrorQueueCodeAll(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Error_Queue_Code);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemErrorQueueCodeNext", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemErrorQueueCodeNext(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Error_Queue_Code_Next);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemErrorQueueCount", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemErrorQueueCount(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Error_Queue_Count);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemStaticErrorQueue", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemStaticErrorQueue(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Error_Queue);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemUSBResource", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemUSBResource(System.Runtime.InteropServices.HandleRef Instrument_Handle, uint Array_Size, System.Text.StringBuilder USB_Resource);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemClearErrorHistory", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemClearErrorHistory(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemRestoreFactorySettings", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemRestoreFactorySettings(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SYSTemShutdown", CallingConvention = CallingConvention.StdCall)]
            public static extern int SYSTemShutdown(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetSYSTemProtect", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetSYSTemProtect(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Protection_Level, ushort Protection, string Password);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemProtect", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemProtect(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Protection_Level, out ushort Protection);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemVersion", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemVersion(System.Runtime.InteropServices.HandleRef Instrument_Handle, System.Text.StringBuilder SCPI_Version);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemStartupStatus", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemStartupStatus(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Startup_Complete);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetSYSTemTerminatorMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetSYSTemTerminatorMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemTerminatorMode", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemTerminatorMode(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Mode);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemDataSheetCatalog", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemDataSheetCatalog(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Sheet_Catalog);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemDataSheetData", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemDataSheetData(System.Runtime.InteropServices.HandleRef Instrument_Handle, string ID, out double Sheet_Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemDataSheetParameter", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemDataSheetParameter(System.Runtime.InteropServices.HandleRef Instrument_Handle, string ID, double Parameter, out double Sheet_Data);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemDataSheetVersion", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemDataSheetVersion(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder Version);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemHwAssemblyNames", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemHwAssemblyNames(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Assembly_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemHwPartNumbers", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemHwPartNumbers(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Assembly_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemHwRevisions", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemHwRevisions(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Assembly_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemHwSerialNumbers", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemHwSerialNumbers(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Assembly_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwFirmwarePackages", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwFirmwarePackages(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwFirmwareVersions", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwFirmwareVersions(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwOptionDesignations", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwOptionDesignations(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Option_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwOptionNames", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwOptionNames(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Option_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwOptionExpirations", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwOptionExpirations(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Option_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetSYSTemSwOptionLicenses", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetSYSTemSwOptionLicenses(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Option_Index, int Array_Size, System.Text.StringBuilder List);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetAngleUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetAngleUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Angle_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetAngleUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetAngleUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Angle_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetPowerUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetPowerUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Power_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetPowerUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetPowerUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Power_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetVelocityUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetVelocityUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Velocity_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetVelocityUnits", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetVelocityUnits(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Velocity_Units);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_SetFormatData", CallingConvention = CallingConvention.StdCall)]
            public static extern int SetFormatData(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Format);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_GetFormatData", CallingConvention = CallingConvention.StdCall)]
            public static extern int GetFormatData(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Format);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_errorCheckState", CallingConvention = CallingConvention.StdCall)]
            public static extern int errorCheckState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State_Checking);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_optionCheckState", CallingConvention = CallingConvention.StdCall)]
            public static extern int optionCheckState(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort State_Checking);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_setCheckRange", CallingConvention = CallingConvention.StdCall)]
            public static extern int setCheckRange(System.Runtime.InteropServices.HandleRef Instrument_Handle, ushort Range_Checking);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_writeInstrData", CallingConvention = CallingConvention.StdCall)]
            public static extern int writeInstrData(System.Runtime.InteropServices.HandleRef Instrument_Handle, string Write_Buffer);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_readInstrData", CallingConvention = CallingConvention.StdCall)]
            public static extern int readInstrData(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Number_Bytes_To_Read, System.Text.StringBuilder Read_Buffer, out int NumBytes_Read);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_reset", CallingConvention = CallingConvention.StdCall)]
            public static extern int reset(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_Clear", CallingConvention = CallingConvention.StdCall)]
            public static extern int Clear(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_self_test", CallingConvention = CallingConvention.StdCall)]
            public static extern int self_test(System.Runtime.InteropServices.HandleRef Instrument_Handle, out short Self_Test_Result, System.Text.StringBuilder Self_Test_Message);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_error_query", CallingConvention = CallingConvention.StdCall)]
            public static extern int error_query(System.Runtime.InteropServices.HandleRef Instrument_Handle, out int Error_Code, System.Text.StringBuilder Error_Message);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_revision_query", CallingConvention = CallingConvention.StdCall)]
            public static extern int revision_query(System.Runtime.InteropServices.HandleRef Instrument_Handle, System.Text.StringBuilder Instrument_Driver_Revision, System.Text.StringBuilder Firmware_Revision);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_delay", CallingConvention = CallingConvention.StdCall)]
            public static extern int delay(System.Runtime.InteropServices.HandleRef Instrument_Handle, double Seconds);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_enumerate_pcie_devices", CallingConvention = CallingConvention.StdCall)]
            public static extern int enumerate_pcie_devices(int Vendor_ID, int Device_ID, [In, Out] int[] Serial_Numbers, out int Array_Size);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_close", CallingConvention = CallingConvention.StdCall)]
            public static extern int close(System.Runtime.InteropServices.HandleRef Instrument_Handle);

            [DllImport("rssgs_32.dll", EntryPoint = "rssgs_error_message", CallingConvention = CallingConvention.StdCall)]
            public static extern int error_message(System.Runtime.InteropServices.HandleRef Instrument_Handle, int Status_Code, System.Text.StringBuilder Message);


            public static int TestForError(System.Runtime.InteropServices.HandleRef handle, int status)
            {
                if ((status < 0))
                {
                    PInvoke.ThrowError(handle, status);
                }
                return status;
            }

            public static int ThrowError(System.Runtime.InteropServices.HandleRef handle, int code)
            {
                System.Text.StringBuilder msg = new System.Text.StringBuilder(256);
                PInvoke.error_message(handle, code, msg);
                throw new System.Runtime.InteropServices.ExternalException(msg.ToString(), code);
            }
        }
    }

    public class rssgsConstants
    {

        public const int RfAttModeAuto = 0;

        public const int RfAttModeFix = 1;

        public const int OperationModeNormal = 0;

        public const int OperationModeBby = 1;

        public const int SourceInt = 0;

        public const int SourceExt = 1;

        public const int LoOutputRef = 0;

        public const int LoOutputLo = 1;

        public const int LoOutputOff = 2;

        public const int RoscRefFreqOf10m = 0;

        public const int RoscRefFreqOf100m = 1;

        public const int RoscRefFreqOf1000m = 2;

        public const int RoscRefFreqOff = 3;

        public const int RoscExtRefFreqEf10m = 0;

        public const int RoscExtRefFreqEf100m = 1;

        public const int RoscExtRefFreqEf1000m = 2;

        public const int RoscExtSyncBwidthWide = 0;

        public const int RoscExtSyncBwidthNarrow = 1;

        public const int LevelModeAuto = 0;

        public const int LevelModeLno = 1;

        public const int LevelModeLdis = 2;

        public const int LevelSettCharactAuto = 0;

        public const int LevelSettCharactUnin = 1;

        public const int LevelSettCharactMon = 2;

        public const int LevelSettCharactCwsw = 3;

        public const int LevelPowOnOff = 0;

        public const int LevelPowOnUnch = 1;

        public const int LevelAlcStateOnt = 0;

        public const int LevelAlcStateOn = 1;

        public const int LevelAlcStateOfft = 2;

        public const int LevelAttOnFix = 0;

        public const int LevelAttOnMax = 1;

        public const int SguHwChannLan = 0;

        public const int SguHwChannUsb = 1;

        public const int SguHwChannPcie = 2;

        public const int SguHwChannSock = 3;

        public const int IpAddressModeAuto = 0;

        public const int IpAddressModeStat = 1;

        public const int RemoteOperModeExt = 0;

        public const int RemoteOperModeStd = 1;

        public const int TrgConOpModeIn = 0;

        public const int TrgConOpModeLo = 1;

        public const int TrgConOpModeMeaslatency = 2;

        public const int TrgConOpModeMeasmsgarrived = 3;

        public const int TrgConOpModeHi = 4;

        public const int TrgConOpModeFbfault = 5;

        public const int TrgConOpModeSignalvalid = 6;

        public const int TrgConOpModeExtout1 = 7;

        public const int TrgConOpModeExtout2 = 8;

        public const int TrgConOpModeBlank = 9;

        public const int RegisterOperation = 0;

        public const int RegisterQuestionable = 1;

        public const int RegisterEnable = 2;

        public const int RegisterNtr = 3;

        public const int RegisterPtr = 4;

        public const int RegisterCond = 0;

        public const int RegisterEvent = 1;

        public const int TerminatorModeEoi = 0;

        public const int TerminatorModeStan = 1;

        public const int AssemblyIndexCommon = 0;

        public const int AssemblyIndexRf = 1;

        public const int OptionIndexHardware = 0;

        public const int OptionIndexSoftware = 1;

        public const int UnitAngleDeg = 0;

        public const int UnitAngleRad = 1;

        public const int UnitPowerV = 0;

        public const int UnitPowerDbm = 1;

        public const int UnitVelocityMps = 0;

        public const int UnitVelocityKmh = 1;

        public const int UnitVelocityMph = 2;

        public const int FormatDataAscii = 0;

        public const int FormatDataPack = 1;
    }
}
